create table TBL_DM_DISTRIBUTION_ASSIGNMENT (
	_id 					integer primary key autoincrement,	
	SRV_PK					integer not null unique ON CONFLICT fail,
    FK_TOUR					integer not null,
    NUMBER					text, 
    VEHICLE_NUMBER			text,
    DRIVER_NAME				text,
    DELIVER_DATE 			integer not null,
	FK_STORE				integer,
	FK_PLANT                integer not null,
	TRANSPORTATION_COMPANY	text,
	IS_CONFIRMED			integer not null,
	CREATE_DATE				integer default (strftime('%s','now')*1000) not null,
	CHANGE_DATE				integer default (strftime('%s','now')*1000) not null,
	foreign key (FK_TOUR) references TBL_DM_TOUR (_id) ON DELETE CASCADE, 
	foreign key (FK_STORE) references TBL_DM_STORE (_id),
	foreign key (FK_PLANT) references TBL_DM_PLANTS (_id)
);

create index idx_TBL_DM_DISTRIBUTION_ASSIGNMENT_PK on TBL_DM_DISTRIBUTION_ASSIGNMENT (_id);
create index idx_TBL_DM_DISTRIBUTION_ASSIGNMENT_SRV_PK on TBL_DM_DISTRIBUTION_ASSIGNMENT (SRV_PK);
create index idx_TBL_DM_DISTRIBUTION_ASSIGNMENT_FK_TOUR on TBL_DM_DISTRIBUTION_ASSIGNMENT (FK_TOUR);
create index idx_TBL_DM_DISTRIBUTION_ASSIGNMENT_NUMBER on TBL_DM_DISTRIBUTION_ASSIGNMENT (NUMBER);
create index idx_TBL_DM_DISTRIBUTION_ASSIGNMENT_DELIVER_DATE on TBL_DM_DISTRIBUTION_ASSIGNMENT (DELIVER_DATE);

create table TBL_DM_DISTRIBUTION_PRODUCT (
	_id 								integer primary key autoincrement,
    FK_DIST_ASSIGNMENT					integer not null,
    FK_PRODUCT		      	        	integer not null,
	FK_LKP_PRODUCT_TYPE                 integer not null,
    FK_FIRST_TRACKING_FACTOR			integer,
    FIRST_TRACKING_FACTOR_VALUE			text,	
    FIRST_TRACKING_FACTOR_VALUE_TITLE	text,
	FIRST_PART_TRACKING_FACTOR 			integer,
    FK_SECOND_TRACKING_FACTOR			integer,
    SECOND_TRACKING_FACTOR_VALUE		text,
    SECOND_TRACKING_FACTOR_VALUE_TITLE	text,
    SECOND_PART_TRACKING_FACTOR			integer,
    FK_THIRD_TRACKING_FACTOR			integer,
    THIRD_TRACKING_FACTOR_VALUE			text,
    THIRD_TRACKING_FACTOR_VALUE_TITLE	text,
    THIRD_PART_TRACKING_FACTOR			integer,
    FK_FOURTH_TRACKING_FACTOR			integer,
    FOURTH_TRACKING_FACTOR_VALUE			text,
    FOURTH_TRACKING_FACTOR_VALUE_TITLE	text,
    FOURTH_PART_TRACKING_FACTOR			integer,
    FK_FIFTH_TRACKING_FACTOR			integer,
    FIFTH_TRACKING_FACTOR_VALUE			text,
    FIFTH_TRACKING_FACTOR_VALUE_TITLE	text,
    FIFTH_PART_TRACKING_FACTOR			integer,				
	CREATE_DATE							integer default (strftime('%s','now')*1000) not null,
	CHANGE_DATE							integer default (strftime('%s','now')*1000) not null,
	foreign key (FK_DIST_ASSIGNMENT) references TBL_DM_DISTRIBUTION_ASSIGNMENT (_id) ON DELETE CASCADE,
	foreign key (FK_PRODUCT) references TBL_DM_PRODUCT (_id),
	foreign key (FK_LKP_PRODUCT_TYPE) references TBL_GN_LOOKUP (_id),
	foreign key (FK_FIRST_TRACKING_FACTOR) references TBL_DM_TRACKING_FACTOR (_id), 
	foreign key (FK_SECOND_TRACKING_FACTOR) references TBL_DM_TRACKING_FACTOR (_id), 
	foreign key (FK_THIRD_TRACKING_FACTOR) references TBL_DM_TRACKING_FACTOR (_id), 
	foreign key (FK_FOURTH_TRACKING_FACTOR) references TBL_DM_TRACKING_FACTOR (_id), 
	foreign key (FK_FIFTH_TRACKING_FACTOR) references TBL_DM_TRACKING_FACTOR (_id) 
);

create index idx_TBL_DM_DISTRIBUTION_PRODUCT_PK on TBL_DM_DISTRIBUTION_PRODUCT (_id);
create index idx_TBL_DM_DISTRIBUTION_PRODUCT_FK_DIST_ASSIGNMENT on TBL_DM_DISTRIBUTION_PRODUCT (FK_DIST_ASSIGNMENT);
create index idx_TBL_DM_DISTRIBUTION_PRODUCT_FK_PRODUCT on TBL_DM_DISTRIBUTION_PRODUCT (FK_PRODUCT);

INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('کالای تجمیعی','1','DISTRIBUTION_PRODUCT_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('کالای فروش گرم','2','DISTRIBUTION_PRODUCT_TYPE');

create table TBL_DM_DIST_PRDT_AMOUNT (
	_id 				integer primary key autoincrement,
    FK_DIST_PRDT		integer not null,
    FK_MEUN			    integer not null,
    QUANTITY			real not null,				
	CREATE_DATE			integer default (strftime('%s','now')*1000) not null,
	CHANGE_DATE			integer default (strftime('%s','now')*1000) not null,
	foreign key (FK_DIST_PRDT) references TBL_DM_DISTRIBUTION_PRODUCT (_id) ON DELETE CASCADE,
	foreign key (FK_MEUN) references TBL_DM_MEASUREMENT_UNIT (_id)
);

create index idx_TBL_DM_DIST_PRDT_AMOUNT_PK on TBL_DM_DIST_PRDT_AMOUNT (_id);
create index idx_TBL_DM_DIST_PRDT_AMOUNT_FK_DIST_PRDT on TBL_DM_DIST_PRDT_AMOUNT (FK_DIST_PRDT);
create index idx_TBL_DM_DIST_PRDT_AMOUNT_FK_MEUN on TBL_DM_DIST_PRDT_AMOUNT (FK_MEUN);

create table TBL_DM_SALES_ASSIGNMENT (
	_id 					integer primary key autoincrement,	
	SRV_PK					integer not null unique ON CONFLICT fail,
	NUMBER					text,
    FK_TOUR_ITEM		    integer not null,
    FK_DIST_ASSIGNMENT	    integer not null,
    FK_SLACC_ACCOUNT		integer null,
    FK_CSMR			      	integer not null,
	DATE					integer,
	SALES_EMPLOYEE_NAME		text,
    FK_PAYAGR				integer null,
    FK_ADRS					integer null,
	PRICE					real not null,
    NET_PRICE				real not null,
    DESCRIPTION				text,
    ADDITION_AMOUNT			real not null,
    REDUCTION_AMOUNT		real not null,
    FK_CRNCY 				integer not null,
    FK_SLTP 				integer not null,
    FK_SLAR 				integer,
    FK_LKP_PAYER_TYPE 		integer not null,
    FK_LKP_STATUS 			integer not null,
    FK_STORE				integer,
    FK_PLANT				integer,
    FK_USRSLOF_REGISTRANT 	integer not null,
    LATITUDE				real,
    LONGITUDE				real,
    FK_LKP_PROVIDER			integer,
    OPERATION_DATE			integer null,
	CREATE_DATE				integer default (strftime('%s','now')*1000) not null,
	CHANGE_DATE				integer default (strftime('%s','now')*1000) not null,
	foreign key (FK_TOUR_ITEM) references TBL_DM_TOUR_ITEM (_id) ON DELETE CASCADE,
	foreign key (FK_DIST_ASSIGNMENT) references TBL_DM_DISTRIBUTION_ASSIGNMENT (_id), 
	foreign key (FK_SLACC_ACCOUNT) references TBL_DM_SALES_ACCOUNT (_id), 
	foreign key (FK_CSMR) references TBL_DM_CUSTOMER (_id),
	foreign key (FK_PAYAGR) references TBL_DM_PAYMENT_AGREEMENT (_id),
	foreign key (FK_ADRS) references TBL_DM_ADDRESS (_id), 
	foreign key (FK_CRNCY) references TBL_DM_CURRENCY (_id),
	foreign key (FK_SLTP) references TBL_DM_SALES_TYPE (_id),
	foreign key (FK_SLAR) references TBL_DM_SALES_AREA (_id), 
	foreign key (FK_LKP_PAYER_TYPE) references TBL_GN_LOOKUP (_id),
	foreign key (FK_LKP_STATUS) references TBL_GN_LOOKUP (_id), 
	foreign key (FK_STORE) references TBL_DM_STORE (_id),
	foreign key (FK_PLANT) references TBL_DM_PLANTS (_id),
	foreign key (FK_USRSLOF_REGISTRANT) references TBL_DM_USER_SALE_OFFICE_INF (_id),
	foreign key (FK_LKP_PROVIDER) references TBL_GN_LOOKUP (_id)
);

create index idx_TBL_DM_SALES_ASSIGNMENT_PK on TBL_DM_SALES_ASSIGNMENT (_id);
create index idx_TBL_DM_SALES_ASSIGNMENT_FK_TOUR_ITEM on TBL_DM_SALES_ASSIGNMENT (FK_TOUR_ITEM);
create index idx_TBL_DM_SALES_ASSIGNMENT_FK_DIST_ASSIGNMENT on TBL_DM_SALES_ASSIGNMENT (FK_DIST_ASSIGNMENT);
create index idx_TBL_DM_SALES_ASSIGNMENT_FK_CSMR on TBL_DM_SALES_ASSIGNMENT (FK_CSMR);

INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('توزیع نشده' ,'1','SALES_ASSIGNMENT_STATUS_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('تحویل شده' ,'2','SALES_ASSIGNMENT_STATUS_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('عدم تحویل' ,'3','SALES_ASSIGNMENT_STATUS_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('تحویل موقت' ,'4','SALES_ASSIGNMENT_STATUS_TYPE');

create table TBL_DM_SALES_ASSIGNMENT_ITEM (
	_id 								integer primary key autoincrement,
	SRV_PK								integer not null unique ON CONFLICT fail,
    ITEM_INDEX							integer not null,
    FK_SALES_ASSIGNMENT		      	    integer not null,
    FK_PRODUCT		      	        	integer not null,
	FK_FIRST_TRACKING_FACTOR			integer,
    FIRST_TRACKING_FACTOR_VALUE			text,	
    FIRST_TRACKING_FACTOR_VALUE_TITLE	text,
	FIRST_PART_TRACKING_FACTOR 			integer,
    FK_SECOND_TRACKING_FACTOR			integer,
    SECOND_TRACKING_FACTOR_VALUE		text,
    SECOND_TRACKING_FACTOR_VALUE_TITLE	text,
    SECOND_PART_TRACKING_FACTOR			integer,
    FK_THIRD_TRACKING_FACTOR			integer,
    THIRD_TRACKING_FACTOR_VALUE			text,
    THIRD_TRACKING_FACTOR_VALUE_TITLE	text,
    THIRD_PART_TRACKING_FACTOR			integer,
    FK_FOURTH_TRACKING_FACTOR			integer,
    FOURTH_TRACKING_FACTOR_VALUE		text,
    FOURTH_TRACKING_FACTOR_VALUE_TITLE	text,
    FOURTH_PART_TRACKING_FACTOR			integer,
    FK_FIFTH_TRACKING_FACTOR			integer,
    FIFTH_TRACKING_FACTOR_VALUE			text,
    FIFTH_TRACKING_FACTOR_VALUE_TITLE	text,
    FIFTH_PART_TRACKING_FACTOR			integer,
    FK_MEUN								integer not null,
    QUANTITY			      			real not null,
    DESCRIPTION							text,
	FK_SLAR								integer not null,
    FEE									real not null,
    PRICE								real not null,
	NET_PRICE							real not null,
    ADDITION_AMOUNT						real not null,
    REDUCTION_AMOUNT					real not null,
    PARENT_ITEM_INDEX					integer,
    FK_SLPLCY_FREE_PRODUCT_POLICY		integer,
    FREE_PRODUCT_CONDITION_ROW_ID		integer, 	
	CREATE_DATE							integer default (strftime('%s','now')*1000) not null,
	CHANGE_DATE							integer default (strftime('%s','now')*1000) not null,
	foreign key (FK_SALES_ASSIGNMENT) references TBL_DM_SALES_ASSIGNMENT (_id) ON DELETE CASCADE,
	foreign key (FK_PRODUCT) references TBL_DM_PRODUCT (_id),
	foreign key (FK_FIRST_TRACKING_FACTOR) references TBL_DM_TRACKING_FACTOR (_id), 
	foreign key (FK_SECOND_TRACKING_FACTOR) references TBL_DM_TRACKING_FACTOR (_id), 
	foreign key (FK_THIRD_TRACKING_FACTOR) references TBL_DM_TRACKING_FACTOR (_id), 
	foreign key (FK_FOURTH_TRACKING_FACTOR) references TBL_DM_TRACKING_FACTOR (_id), 
	foreign key (FK_FIFTH_TRACKING_FACTOR) references TBL_DM_TRACKING_FACTOR (_id),
	foreign key (FK_MEUN) references TBL_DM_MEASUREMENT_UNIT (_id), 
	foreign key (FK_SLAR) references TBL_DM_SALES_AREA (_id),
	foreign key (FK_SLPLCY_FREE_PRODUCT_POLICY) references TBL_DM_SALES_POLICY (_id)
);

create index idx_TBL_DM_SALES_ASSIGNMENT_ITEM_PK on TBL_DM_SALES_ASSIGNMENT_ITEM (_id);
create index idx_TBL_DM_SALES_ASSIGNMENT_ITEM_SRV_PK on TBL_DM_SALES_ASSIGNMENT_ITEM (SRV_PK);
create index idx_TBL_DM_SALES_ASSIGNMENT_ITEM_FK_SALES_ASSIGNMENT on TBL_DM_SALES_ASSIGNMENT_ITEM (FK_SALES_ASSIGNMENT);

create table TBL_DM_SALES_ASSIGNMENT_POLICY_RESULT (
	_id 						integer primary key autoincrement,	
    FK_SLPLCY					integer not null,
    FK_SALES_ASSIGNMENT			integer,
    FK_SALES_ASSIGNMENT_ITEM	integer,
    VALUE						real,
    VALUE_TITLE			    	integer,
    AMOUNT						real,
	IS_VALUE_CHANGED			integer not null,
    IS_ALLOTMENTED				integer not null,
	CREATE_DATE					integer default (strftime('%s','now')*1000) not null,
	CHANGE_DATE					integer default (strftime('%s','now')*1000) not null,
	foreign key (FK_SLPLCY) references TBL_DM_SALES_POLICY (_id) ON DELETE CASCADE,
	foreign key (FK_SALES_ASSIGNMENT) references TBL_DM_SALES_ASSIGNMENT (_id) ON DELETE CASCADE,
	foreign key (FK_SALES_ASSIGNMENT_ITEM) references TBL_DM_SALES_ASSIGNMENT_ITEM (_id) ON DELETE CASCADE	
);

create index idx_TBL_DM_SALES_ASSIGNMENT_POLICY_RESULT_PK on TBL_DM_SALES_ASSIGNMENT_POLICY_RESULT (_id);
create index idx_TBL_DM_SALES_ASSIGNMENT_POLICY_RESULT_FK_SLPLCY on TBL_DM_SALES_ASSIGNMENT_POLICY_RESULT (FK_SLPLCY);
create index idx_TBL_DM_SALES_ASSIGNMENT_POLICY_RESULT_FK_SALES_ASSIGNMENT on TBL_DM_SALES_ASSIGNMENT_POLICY_RESULT (FK_SALES_ASSIGNMENT);
create index idx_TBL_DM_SALES_ASSIGNMENT_POLICY_RESULT_FK_SALES_ASSIGNMENT_ITEM on TBL_DM_SALES_ASSIGNMENT_POLICY_RESULT (FK_SALES_ASSIGNMENT_ITEM);

create table TBL_DM_RETURN_PERMIT (
	_id 					integer primary key autoincrement,	
	SRV_PK					integer not null unique ON CONFLICT fail,
	NUMBER					text,
    FK_TOUR_ITEM		    integer not null,
    FK_DIST_ASSIGNMENT	    integer not null,
    FK_SLACC_ACCOUNT		integer null,
    FK_CSMR			      	integer not null,
	DATE					integer,
	SALES_EMPLOYEE_NAME		text,
    FK_ADRS					integer null,
	PRICE					real not null,
    NET_PRICE				real not null,
    DESCRIPTION				text,
    ADDITION_AMOUNT			real not null,
    REDUCTION_AMOUNT		real not null,
    FK_CRNCY 				integer not null,
    FK_SLTP 				integer not null,
    FK_SLAR 				integer,
    FK_LKP_PAYER_TYPE 		integer not null,
    FK_LKP_STATUS 			integer not null,
    FK_PLANT				integer,
    FK_USRSLOF_REGISTRANT 	integer not null,
    LATITUDE				real,
    LONGITUDE				real,
    FK_LKP_PROVIDER			integer,
    OPERATION_DATE			integer null,
	CREATE_DATE				integer default (strftime('%s','now')*1000) not null,
	CHANGE_DATE				integer default (strftime('%s','now')*1000) not null,
	foreign key (FK_TOUR_ITEM) references TBL_DM_TOUR_ITEM (_id) ON DELETE CASCADE,
	foreign key (FK_DIST_ASSIGNMENT) references TBL_DM_DISTRIBUTION_ASSIGNMENT (_id), 
	foreign key (FK_SLACC_ACCOUNT) references TBL_DM_SALES_ACCOUNT (_id), 
	foreign key (FK_CSMR) references TBL_DM_CUSTOMER (_id),
	foreign key (FK_ADRS) references TBL_DM_ADDRESS (_id), 
	foreign key (FK_CRNCY) references TBL_DM_CURRENCY (_id),
	foreign key (FK_SLTP) references TBL_DM_SALES_TYPE (_id),
	foreign key (FK_SLAR) references TBL_DM_SALES_AREA (_id), 
	foreign key (FK_LKP_PAYER_TYPE) references TBL_GN_LOOKUP (_id),
	foreign key (FK_LKP_STATUS) references TBL_GN_LOOKUP (_id),
	foreign key (FK_PLANT) references TBL_DM_PLANTS (_id),
	foreign key (FK_USRSLOF_REGISTRANT) references TBL_DM_USER_SALE_OFFICE_INF (_id),
	foreign key (FK_LKP_PROVIDER) references TBL_GN_LOOKUP (_id)
);

create index idx_TBL_DM_RETURN_PERMIT_PK on TBL_DM_RETURN_PERMIT (_id);
create index idx_TBL_DM_RETURN_PERMIT_FK_TOUR_ITEM on TBL_DM_RETURN_PERMIT (FK_TOUR_ITEM);
create index idx_TBL_DM_RETURN_PERMIT_FK_DIST_ASSIGNMENT on TBL_DM_RETURN_PERMIT (FK_DIST_ASSIGNMENT);
create index idx_TBL_DM_RETURN_PERMIT_FK_CSMR on TBL_DM_RETURN_PERMIT (FK_CSMR);

INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('برگشت نشده', '1','RETURN_PERMIT_STATUS_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('برگشت شده', '2','RETURN_PERMIT_STATUS_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('عدم برگشت', '3','RETURN_PERMIT_STATUS_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('برگشت موقت', '4','RETURN_PERMIT_STATUS_TYPE');

create table TBL_DM_RETURN_PERMIT_ITEM (
	_id 								integer primary key autoincrement,
	SRV_PK								integer not null unique ON CONFLICT fail,
    ITEM_INDEX							integer not null,
    FK_RETURN_PERMIT		      	    integer not null,
    FK_PRODUCT		      	        	integer not null,
    FK_RETURN_REASON				integer null,
	FK_FIRST_TRACKING_FACTOR			integer,
    FIRST_TRACKING_FACTOR_VALUE			text,	
    FIRST_TRACKING_FACTOR_VALUE_TITLE	text,
	FIRST_PART_TRACKING_FACTOR 			integer,
    FK_SECOND_TRACKING_FACTOR			integer,
    SECOND_TRACKING_FACTOR_VALUE		text,
    SECOND_TRACKING_FACTOR_VALUE_TITLE	text,
    SECOND_PART_TRACKING_FACTOR			integer,
    FK_THIRD_TRACKING_FACTOR			integer,
    THIRD_TRACKING_FACTOR_VALUE			text,
    THIRD_TRACKING_FACTOR_VALUE_TITLE	text,
    THIRD_PART_TRACKING_FACTOR			integer,
    FK_FOURTH_TRACKING_FACTOR			integer,
    FOURTH_TRACKING_FACTOR_VALUE		text,
    FOURTH_TRACKING_FACTOR_VALUE_TITLE	text,
    FOURTH_PART_TRACKING_FACTOR			integer,
    FK_FIFTH_TRACKING_FACTOR			integer,
    FIFTH_TRACKING_FACTOR_VALUE			text,
    FIFTH_TRACKING_FACTOR_VALUE_TITLE	text,
    FIFTH_PART_TRACKING_FACTOR			integer,
    FK_MEUN								integer not null,
    QUANTITY			      			real not null,
    DESCRIPTION							text,
	FK_SLAR								integer not null,
    FEE									real not null,
    PRICE								real not null,
	NET_PRICE							real not null,
    ADDITION_AMOUNT						real not null,
    REDUCTION_AMOUNT					real not null,
    PARENT_ITEM_INDEX					integer,
    FK_SLPLCY_FREE_PRODUCT_POLICY		integer,
    FREE_PRODUCT_CONDITION_ROW_ID		integer, 	
	CREATE_DATE							integer default (strftime('%s','now')*1000) not null,
	CHANGE_DATE							integer default (strftime('%s','now')*1000) not null,
	foreign key (FK_RETURN_PERMIT) references TBL_DM_RETURN_PERMIT (_id) ON DELETE CASCADE,
	foreign key (FK_PRODUCT) references TBL_DM_PRODUCT (_id),
	foreign key (FK_FIRST_TRACKING_FACTOR) references TBL_DM_TRACKING_FACTOR (_id), 
	foreign key (FK_SECOND_TRACKING_FACTOR) references TBL_DM_TRACKING_FACTOR (_id), 
	foreign key (FK_THIRD_TRACKING_FACTOR) references TBL_DM_TRACKING_FACTOR (_id), 
	foreign key (FK_FOURTH_TRACKING_FACTOR) references TBL_DM_TRACKING_FACTOR (_id), 
	foreign key (FK_FIFTH_TRACKING_FACTOR) references TBL_DM_TRACKING_FACTOR (_id) 
	foreign key (FK_MEUN) references TBL_DM_MEASUREMENT_UNIT (_id), 
	foreign key (FK_SLAR) references TBL_DM_SALES_AREA (_id),
	foreign key (FK_SLPLCY_FREE_PRODUCT_POLICY) references TBL_DM_SALES_POLICY (_id),
	foreign key (FK_RETURN_REASON) references TBL_DM_RETURN_REASON (_id)
);

create index idx_TBL_DM_RETURN_PERMIT_ITEM_PK on TBL_DM_RETURN_PERMIT_ITEM (_id);
create index idx_TBL_DM_RETURN_PERMIT_ITEM_SRV_PK on TBL_DM_RETURN_PERMIT_ITEM (SRV_PK);
create index idx_TBL_DM_RETURN_PERMIT_ITEM_FK_RETURN_PERMIT on TBL_DM_RETURN_PERMIT_ITEM (FK_RETURN_PERMIT);

create table TBL_DM_RETURN_PERMIT_POLICY_RESULT (
	_id 						integer primary key autoincrement,	
    FK_SLPLCY					integer not null,
    FK_RETURN_PERMIT			integer,
    FK_RETURN_PERMIT_ITEM		integer,
    VALUE						real,
    VALUE_TITLE			    	integer,
    AMOUNT						real,
	IS_VALUE_CHANGED			integer not null,
    IS_ALLOTMENTED				integer not null,
	CREATE_DATE					integer default (strftime('%s','now')*1000) not null,
	CHANGE_DATE					integer default (strftime('%s','now')*1000) not null,
	foreign key (FK_SLPLCY) references TBL_DM_SALES_POLICY (_id) ON DELETE CASCADE,
	foreign key (FK_RETURN_PERMIT) references TBL_DM_RETURN_PERMIT (_id) ON DELETE CASCADE,
	foreign key (FK_RETURN_PERMIT_ITEM) references TBL_DM_RETURN_PERMIT_ITEM (_id) ON DELETE CASCADE
);

create index idx_TBL_DM_RETURN_PERMIT_POLICY_RESULT_PK on TBL_DM_RETURN_PERMIT_POLICY_RESULT (_id);
create index idx_TBL_DM_RETURN_PERMIT_POLICY_RESULT_FK_SLPLCY on TBL_DM_RETURN_PERMIT_POLICY_RESULT (FK_SLPLCY);
create index idx_TBL_DM_RETURN_PERMIT_POLICY_RESULT_FK_RETURN_PERMIT on TBL_DM_RETURN_PERMIT_POLICY_RESULT (FK_RETURN_PERMIT);
create index idx_TBL_DM_RETURN_PERMIT_POLICY_RESULT_FK_RETURN_PERMIT_ITEM on TBL_DM_RETURN_PERMIT_POLICY_RESULT (FK_RETURN_PERMIT_ITEM);

create table TBL_DM_COLD_DEFINITIVE_INVOICE (
	_id 					integer primary key autoincrement,	
	SRV_PK					integer not null unique ON CONFLICT fail,
	NUMBER					text,
    FK_TOUR_ITEM		    integer not null,
    FK_DIST_ASSIGNMENT	    integer not null,
    FK_SLACC_ACCOUNT		integer null,
    FK_CSMR			      	integer not null,
	DATE					integer,
	SALES_EMPLOYEE_NAME		text,
    FK_PAYAGR				integer null,
    FK_ADRS					integer null,
	PRICE					real not null,
    NET_PRICE				real not null,
    DESCRIPTION				text,
    ADDITION_AMOUNT			real not null,
    REDUCTION_AMOUNT		real not null,
    FK_CRNCY 				integer not null,
    FK_SLTP 				integer not null,
    FK_SLAR 				integer,
    FK_LKP_PAYER_TYPE 		integer not null,
    FK_LKP_STATUS 			integer not null,
    FK_STORE				integer,
    FK_PLANT				integer,
    FK_USRSLOF_REGISTRANT 	integer not null,
    LATITUDE				real,
    LONGITUDE				real,
    FK_LKP_PROVIDER			integer,
    OPERATION_DATE			integer null,
	CREATE_DATE				integer default (strftime('%s','now')*1000) not null,
	CHANGE_DATE				integer default (strftime('%s','now')*1000) not null,
	foreign key (FK_TOUR_ITEM) references TBL_DM_TOUR_ITEM (_id) ON DELETE CASCADE,
	foreign key (FK_DIST_ASSIGNMENT) references TBL_DM_DISTRIBUTION_ASSIGNMENT (_id), 
	foreign key (FK_SLACC_ACCOUNT) references TBL_DM_SALES_ACCOUNT (_id), 
	foreign key (FK_CSMR) references TBL_DM_CUSTOMER (_id),
	foreign key (FK_PAYAGR) references TBL_DM_PAYMENT_AGREEMENT (_id),
	foreign key (FK_ADRS) references TBL_DM_ADDRESS (_id), 
	foreign key (FK_CRNCY) references TBL_DM_CURRENCY (_id),
	foreign key (FK_SLTP) references TBL_DM_SALES_TYPE (_id),
	foreign key (FK_SLAR) references TBL_DM_SALES_AREA (_id), 
	foreign key (FK_LKP_PAYER_TYPE) references TBL_GN_LOOKUP (_id),
	foreign key (FK_LKP_STATUS) references TBL_GN_LOOKUP (_id),
	foreign key (FK_STORE) references TBL_DM_STORE (_id),
	foreign key (FK_PLANT) references TBL_DM_PLANTS (_id),
	foreign key (FK_USRSLOF_REGISTRANT) references TBL_DM_USER_SALE_OFFICE_INF (_id),
	foreign key (FK_LKP_PROVIDER) references TBL_GN_LOOKUP (_id)
);

create index idx_TBL_DM_COLD_DEFINITIVE_INVOICE_PK on TBL_DM_COLD_DEFINITIVE_INVOICE (_id);
create index idx_TBL_DM_COLD_DEFINITIVE_INVOICE_FK_TOUR_ITEM on TBL_DM_COLD_DEFINITIVE_INVOICE (FK_TOUR_ITEM);
create index idx_TBL_DM_COLD_DEFINITIVE_INVOICE_FK_DIST_ASSIGNMENT on TBL_DM_COLD_DEFINITIVE_INVOICE (FK_DIST_ASSIGNMENT);
create index idx_TBL_DM_COLD_DEFINITIVE_INVOICE_FK_CSMR on TBL_DM_COLD_DEFINITIVE_INVOICE (FK_CSMR);

INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('دریافت شده','1','COLD_DEFINITIVE_INVOICE_STATUS_TYPE');

create table TBL_DM_COLD_DEFINITIVE_INVOICE_ITEM (
	_id 								integer primary key autoincrement,
	SRV_PK								integer not null unique ON CONFLICT fail,
    ITEM_INDEX							integer not null,
    FK_COLD_DEFINITIVE_INVOICE     	    integer not null,
    FK_PRODUCT		      	        	integer not null,
	FK_FIRST_TRACKING_FACTOR			integer,
    FIRST_TRACKING_FACTOR_VALUE			text,	
    FIRST_TRACKING_FACTOR_VALUE_TITLE	text,
	FIRST_PART_TRACKING_FACTOR 			integer,
    FK_SECOND_TRACKING_FACTOR			integer,
    SECOND_TRACKING_FACTOR_VALUE		text,
    SECOND_TRACKING_FACTOR_VALUE_TITLE	text,
    SECOND_PART_TRACKING_FACTOR			integer,
    FK_THIRD_TRACKING_FACTOR			integer,
    THIRD_TRACKING_FACTOR_TITLE			text,
    THIRD_TRACKING_FACTOR_VALUE_TITLE	text,
    THIRD_PART_TRACKING_FACTOR			integer,
    FK_FOURTH_TRACKING_FACTOR			integer,
    FOURTH_TRACKING_FACTOR_TITLE		text,
    FOURTH_TRACKING_FACTOR_VALUE_TITLE	text,
    FOURTH_PART_TRACKING_FACTOR			integer,
    FK_FIFTH_TRACKING_FACTOR			integer,
    FIFTH_TRACKING_FACTOR_TITLE			text,
    FIFTH_TRACKING_FACTOR_VALUE_TITLE	text,
    FIFTH_PART_TRACKING_FACTOR			integer,
    FK_MEUN								integer not null,
    QUANTITY			      			real not null,
    DESCRIPTION							text,
	FK_SLAR								integer not null,
    FEE									real not null,
    PRICE								real not null,
	NET_PRICE							real not null,
    ADDITION_AMOUNT						real not null,
    REDUCTION_AMOUNT					real not null,
    PARENT_ITEM_INDEX					integer,
    FK_SLPLCY_FREE_PRODUCT_POLICY		integer,
    FREE_PRODUCT_CONDITION_ROW_ID		integer, 	
	CREATE_DATE							integer default (strftime('%s','now')*1000) not null,
	CHANGE_DATE							integer default (strftime('%s','now')*1000) not null,
	foreign key (FK_COLD_DEFINITIVE_INVOICE) references TBL_DM_COLD_DEFINITIVE_INVOICE (_id) ON DELETE CASCADE,
	foreign key (FK_PRODUCT) references TBL_DM_PRODUCT (_id),
	foreign key (FK_FIRST_TRACKING_FACTOR) references TBL_DM_TRACKING_FACTOR (_id), 
	foreign key (FK_SECOND_TRACKING_FACTOR) references TBL_DM_TRACKING_FACTOR (_id), 
	foreign key (FK_THIRD_TRACKING_FACTOR) references TBL_DM_TRACKING_FACTOR (_id), 
	foreign key (FK_FOURTH_TRACKING_FACTOR) references TBL_DM_TRACKING_FACTOR (_id), 
	foreign key (FK_FIFTH_TRACKING_FACTOR) references TBL_DM_TRACKING_FACTOR (_id) 
	foreign key (FK_MEUN) references TBL_DM_MEASUREMENT_UNIT (_id), 
	foreign key (FK_SLAR) references TBL_DM_SALES_AREA (_id),
	foreign key (FK_SLPLCY_FREE_PRODUCT_POLICY) references TBL_DM_SALES_POLICY (_id)
);

create index idx_TBL_DM_COLD_DEFINITIVE_INVOICE_ITEM_PK on TBL_DM_COLD_DEFINITIVE_INVOICE_ITEM (_id);
create index idx_TBL_DM_COLD_DEFINITIVE_INVOICE_ITEM_SRV_PK on TBL_DM_COLD_DEFINITIVE_INVOICE_ITEM (SRV_PK);
create index idx_TBL_DM_COLD_DEFINITIVE_INVOICE_ITEM_FK_COLD_DEFINITIVE_INVOICE on TBL_DM_COLD_DEFINITIVE_INVOICE_ITEM (FK_COLD_DEFINITIVE_INVOICE);

create table TBL_DM_COLD_DEFINITIVE_INVOICE_POLICY_RESULT (
	_id 							integer primary key autoincrement,	
    FK_SLPLCY						integer not null,
    FK_COLD_DEFINITIVE_INVOICE		integer,
    FK_COLD_DEFINITIVE_INVOICE_ITEM	integer,
    VALUE							real,
    VALUE_TITLE			    		integer,
    AMOUNT							real,
	IS_VALUE_CHANGED				integer not null,
    IS_ALLOTMENTED					integer not null,
	CREATE_DATE						integer default (strftime('%s','now')*1000) not null,
	CHANGE_DATE						integer default (strftime('%s','now')*1000) not null,
	foreign key (FK_SLPLCY) references TBL_DM_SALES_POLICY (_id) ON DELETE CASCADE,
	foreign key (FK_COLD_DEFINITIVE_INVOICE) references TBL_DM_COLD_DEFINITIVE_INVOICE (_id) ON DELETE CASCADE,
	foreign key (FK_COLD_DEFINITIVE_INVOICE_ITEM) references TBL_DM_COLD_DEFINITIVE_INVOICE_ITEM (_id) ON DELETE CASCADE
);

create index idx_TBL_DM_COLD_DEFINITIVE_INVOICE_POLICY_RESULT_PK on TBL_DM_COLD_DEFINITIVE_INVOICE_POLICY_RESULT (_id);
create index idx_TBL_DM_COLD_DEFINITIVE_INVOICE_POLICY_RESULT_FK_SLPLCY on TBL_DM_COLD_DEFINITIVE_INVOICE_POLICY_RESULT (FK_SLPLCY);
create index idx_TBL_DM_COLD_DEFINITIVE_INVOICE_POLICY_RESULT_FK_COLD_DEFINITIVE_INVOICE on TBL_DM_COLD_DEFINITIVE_INVOICE_POLICY_RESULT (FK_COLD_DEFINITIVE_INVOICE);
create index idx_TBL_DM_COLD_DEFINITIVE_INVOICE_POLICY_RESULT_FK_COLD_DEFINITIVE_INVOICE_ITEM on TBL_DM_COLD_DEFINITIVE_INVOICE_POLICY_RESULT (FK_COLD_DEFINITIVE_INVOICE_ITEM);

