CREATE TABLE TBL_DM_COLD_NON_DEFINITIVE_INVOICE (
	_id 					integer primary key autoincrement,
	GUID 					text not null unique ON CONFLICT fail,
	NUMBER 					text null, 
	REGISTER_DATE 			integer not null default (strftime('%s','now') * 1000),
	IS_DELETED 				integer not null default 0,
	FK_USRSLOF_REGISTRANT 	integer not null,
	FK_CSMR 				integer not null,
	FK_ADRS 				integer null, 
	FK_PAYAGR 				integer null, 
	FK_TIAC 				integer not null, 
	DESCRIPTION 			text null,
	SALES_EMPLOYEE_NAME		text null,
	IS_CALCULATED 			integer not null default 0, 
	FK_SALES_ASSIGNMENT 	integer not null, 
	FK_CRNCY 				integer not null, 
	FK_LOCATION				integer null, 
	FK_SLTP 				integer not null,
	FK_SLAR 				integer null, 
	FK_LKP_PAYER_TYPE 		integer not null,
	FK_LKP_STATUS 			integer not null,
	FK_SLACC_ACCOUNT 		integer null,
	FK_SRV_ERR 				integer null,
	FK_PLANT 				integer null,
	FK_STORE 				integer null,
	PRICE 					real not null default 0, 
	NET_PRICE 				real not null default 0, 
	ADDITION_AMOUNT 		real not null default 0, 
	REDUCTION_AMOUNT 		real not null default 0, 
	IS_PRINTED 				integer not null default 0,
	OPERATION_DATE			integer null,
	CREATE_DATE 			integer not null default (strftime('%s','now') * 1000),
	CHANGE_DATE 			integer not null default (strftime('%s','now') * 1000),
	foreign key (FK_SALES_ASSIGNMENT) references TBL_DM_SALES_ASSIGNMENT (_id) ON DELETE CASCADE UNIQUE (FK_SALES_ASSIGNMENT) ON CONFLICT ROLLBACK, 
	foreign key (FK_TIAC) references TBL_DM_TOUR_ITEM_ACTIVITY (_id) ON DELETE CASCADE,
	foreign key (FK_CSMR) references TBL_DM_CUSTOMER (_id),
	foreign key (FK_ADRS) references TBL_DM_ADDRESS (_id),
	foreign key (FK_PAYAGR) references TBL_DM_PAYMENT_AGREEMENT (_id),
	foreign key (FK_SLAR) references TBL_DM_SALES_AREA (_id),
	foreign key (FK_SLTP) references TBL_DM_SALES_TYPE (_id),
	foreign key (FK_USRSLOF_REGISTRANT) references TBL_DM_USER_SALE_OFFICE_INF (_id),
	foreign key (FK_CRNCY) references TBL_DM_CURRENCY (_id),
	foreign key (FK_LOCATION) references TBL_DM_LOCATION (_id) ON DELETE CASCADE,
	foreign key (FK_LKP_PAYER_TYPE) references TBL_GN_LOOKUP (_id),
	foreign key (FK_SRV_ERR) references TBL_DM_ERROR_MESSAGE (_id),
	foreign key (FK_PLANT) references TBL_DM_PLANTS (_id),
	foreign key (FK_STORE) references TBL_DM_STORE (_id),
	foreign key (FK_SLACC_ACCOUNT) references TBL_DM_SALES_ACCOUNT (_id),
	foreign key (FK_LKP_STATUS) references TBL_GN_LOOKUP (_id)
);

create index idx_TBL_DM_COLD_NON_DEFINITIVE_INVOICE_PK on TBL_DM_COLD_NON_DEFINITIVE_INVOICE (_id);
create index idx_TBL_DM_COLD_NON_DEFINITIVE_INVOICE_FK_CSMR on TBL_DM_COLD_NON_DEFINITIVE_INVOICE (FK_CSMR);
create index idx_TBL_DM_COLD_NON_DEFINITIVE_INVOICE_FK_TIAC on TBL_DM_COLD_NON_DEFINITIVE_INVOICE (FK_TIAC);
create index idx_TBL_DM_COLD_NON_DEFINITIVE_INVOICE_FK_SALES_ASSIGNMENT on TBL_DM_COLD_NON_DEFINITIVE_INVOICE (FK_SALES_ASSIGNMENT);

CREATE TABLE TBL_DM_COLD_NON_DEFINITIVE_INVOICE_ITEM (
	_id 							integer primary key autoincrement, 
	FK_COLD_NON_DEFINITIVE_INVOICE 	integer not null, 
	FK_SALES_ASSIGNMENT_ITEM 		integer null,
	PRIORITY 						integer not null, 
	IS_DELETED 						integer not null default 0, 
	QUANTITY 						real not null, 
	FK_PRDT_MEUN 					integer not null, 
	FK_SLAR 						integer not null, 
	DESCRIPTION 					text null, 
	FEE 							real not null default 0, 
	PRICE 							real not null default 0, 
	NET_PRICE 						real not null default 0, 
	ADDITION_AMOUNT 				real not null default 0, 
	REDUCTION_AMOUNT 				real not null default 0, 
	FK_INVOICE_ITEM_PARENT 			integer null, 
	FK_SLPLCY_FREE_PRODUCT_POLICY 	integer null, 
	FREE_PRODUCT_CONDITION_ROW_ID 	integer, 
	CREATE_DATE 					integer not null default (strftime('%s','now') * 1000),
	CHANGE_DATE 					integer not null default (strftime('%s','now') * 1000),
	foreign key (FK_COLD_NON_DEFINITIVE_INVOICE) references TBL_DM_COLD_NON_DEFINITIVE_INVOICE (_id) ON DELETE CASCADE, 
	foreign key (FK_SALES_ASSIGNMENT_ITEM) references TBL_DM_SALES_ASSIGNMENT_ITEM (_id) ON DELETE CASCADE,
	foreign key (FK_PRDT_MEUN) references TBL_DM_PRDT_MEUN_INF (_id), 
	foreign key (FK_SLAR) references TBL_DM_SALES_AREA (_id),
	foreign key (FK_INVOICE_ITEM_PARENT) references TBL_DM_COLD_NON_DEFINITIVE_INVOICE_ITEM (_id), 
	foreign key (FK_SLPLCY_FREE_PRODUCT_POLICY) references TBL_DM_SALES_POLICY (_id) UNIQUE (FK_COLD_NON_DEFINITIVE_INVOICE, FK_PRDT_MEUN, FK_INVOICE_ITEM_PARENT) ON CONFLICT ROLLBACK
);

create index idx_TBL_DM_COLD_NON_DEFINITIVE_INVOICE_ITEM_PK on TBL_DM_COLD_NON_DEFINITIVE_INVOICE_ITEM (_id);
create index idx_TBL_DM_COLD_NON_DEFINITIVE_INVOICE_ITEM_FK_COLD_NON_DEFINITIVE_INVOICE on TBL_DM_COLD_NON_DEFINITIVE_INVOICE_ITEM (FK_COLD_NON_DEFINITIVE_INVOICE);
create index idx_TBL_DM_COLD_NON_DEFINITIVE_INVOICE_ITEM_FK_SALES_ASSIGNMENT_ITEM on TBL_DM_COLD_NON_DEFINITIVE_INVOICE_ITEM (FK_SALES_ASSIGNMENT_ITEM);

CREATE TABLE TBL_DM_COLD_NON_DEFINITIVE_INVOICE_POLICY_RESULT (
	_id 								integer primary key autoincrement, 
	VALUE 								real null, 
	VALUE_TITLE 						text not null, 
	AMOUNT 								real, 
	IS_ALLOTMENTED 						integer not null, 
	IS_VALUE_CHANGED 					integer not null, 
	FK_SLPLCY 							integer not null, 
	FK_COLD_NON_DEFINITIVE_INVOICE 		integer null, 
	FK_COLD_NON_DEFINITIVE_INVOICE_ITEM integer null, 
	CREATE_DATE 						integer not null default (strftime('%s','now') * 1000),
	CHANGE_DATE 						integer not null default (strftime('%s','now') * 1000),
	foreign key (FK_COLD_NON_DEFINITIVE_INVOICE) references TBL_DM_COLD_NON_DEFINITIVE_INVOICE (_id) ON DELETE CASCADE,
	foreign key (FK_COLD_NON_DEFINITIVE_INVOICE_ITEM) references TBL_DM_COLD_NON_DEFINITIVE_INVOICE_ITEM (_id) ON DELETE CASCADE,
	foreign key (FK_SLPLCY) references TBL_DM_SALES_POLICY (_id)
);

create index idx_TBL_DM_COLD_NON_DEFINITIVE_INVOICE_POLICY_RESULT_PK on TBL_DM_COLD_NON_DEFINITIVE_INVOICE_POLICY_RESULT (_id);
create index idx_TBL_DM_COLD_NON_DEFINITIVE_INVOICE_POLICY_RESULT_FK_COLD_NON_DEFINITIVE_INVOICE on TBL_DM_COLD_NON_DEFINITIVE_INVOICE_POLICY_RESULT (FK_COLD_NON_DEFINITIVE_INVOICE);
create index idx_TBL_DM_COLD_NON_DEFINITIVE_INVOICE_POLICY_RESULT_FK_COLD_NON_DEFINITIVE_INVOICE_ITEM on TBL_DM_COLD_NON_DEFINITIVE_INVOICE_POLICY_RESULT (FK_COLD_NON_DEFINITIVE_INVOICE_ITEM);

