CREATE TABLE TBL_DM_CUSTOMER_SURVEY(
  _id INTEGER PRIMARY KEY autoincrement,
  SRV_PK          INTEGER ,
  NAME            TEXT ,
  TYPE            INTEGER ,
  SUB_TYPE        INTEGER ,
  ENTITY_TITLE    TEXT ,
  ENTITY_ID       INTEGER ,
  IS_DELETED      INTEGER NOT NULL DEFAULT 0,
  IS_ACTIVE       INTEGER NOT NULL DEFAULT 1,
  CREATE_DATE		  INTEGER NOT NULL DEFAULT (strftime('%s','now')*1000),
	CHANGE_DATE		  INTEGER NOT NULL DEFAULT (strftime('%s','now')*1000)
);
CREATE index idx_TBL_DM_CUSTOMER_SURVEY  ON TBL_DM_CUSTOMER_SURVEY (_id);

CREATE TABLE TBL_DM_SURVEY_ENTITY(
  _id                 INTEGER PRIMARY KEY autoincrement,
  SRV_PK              INTEGER ,
  ROW_NO              INTEGER ,
  NAME                TEXT ,
  IS_MANDATORY        INTEGER ,
  UNIT_IDS            TEXT,
  ENTITY_TYPE         INTEGER ,
  IS_DYNAMIC          INTEGER  NOT NULL DEFAULT 0
);
CREATE index idx_TBL_DM_SURVEY_ENTITY   ON TBL_DM_SURVEY_ENTITY (_id);

CREATE TABLE TBL_DM_SURVEY_ENTITY_GROUP(
  _id                 INTEGER PRIMARY KEY autoincrement,
  SRV_PK              INTEGER ,
  FK_ENTITY_PARENT    INTEGER ,
  NAME                TEXT
);
CREATE index idx_TBL_DM_SURVEY_ENTITY_GROUP                     ON TBL_DM_SURVEY_ENTITY_GROUP (_id);
CREATE index idx_TBL_DM_SURVEY_ENTITY_GROUP_FK_ENTITY_PARENT    ON TBL_DM_SURVEY_ENTITY_GROUP (FK_ENTITY_PARENT);

CREATE TABLE TBL_DM_SURVEY_FIELD_SPEC(
  _id                 INTEGER PRIMARY KEY autoincrement ,
  SRV_PK              INTEGER ,
  ROW_NO              INTEGER ,
  TYPE                INTEGER ,
  NAME                TEXT ,
  IS_MANDATORY        INTEGER ,
  UNIT_BASED          INTEGER ,
  USE_ENTITY_UNITS    INTEGER ,
  PIC_SIZE            INTEGER
);
CREATE index idx_TBL_DM_SURVEY_FIELD_SPEC  ON TBL_DM_SURVEY_FIELD_SPEC (_id);

CREATE TABLE TBL_DM_SURVEY_LOOKUP(
  _id           INTEGER PRIMARY KEY autoincrement ,
  SRV_PK        INTEGER ,
  NAME          TEXT
);
CREATE index idx_TBL_DM_SURVEY_LOOKUP  ON TBL_DM_SURVEY_LOOKUP (_id);

CREATE TABLE TBL_DM_SURVEY_ACT_DEPENDENCY(
  _id                                   INTEGER PRIMARY KEY autoincrement ,
  ACTIVITY_TYPE                         INTEGER ,
  IS_MANDATORY_IN_NON_PLANNED_ACTIVITY  INTEGER ,
  FK_CUSTOMER_SURVEY                    INTEGER ,
  FOREIGN KEY   (FK_CUSTOMER_SURVEY)  REFERENCES TBL_DM_CUSTOMER_SURVEY (_id)  ON DELETE CASCADE
);
CREATE index idx_TBL_DM_SURVEY_ACT_DEPENDENCY                     ON TBL_DM_SURVEY_ACT_DEPENDENCY (_id);
CREATE index idx_TBL_DM_SURVEY_ACT_DEPENDENCY_FK_CUSTOMER_SURVEY  ON TBL_DM_SURVEY_ACT_DEPENDENCY (FK_CUSTOMER_SURVEY);

CREATE TABLE TBL_DM_SURVEY_RELATION_ENTITY_INF(
  _id                 INTEGER PRIMARY KEY autoincrement ,
  FK_CUSTOMER_SURVEY  INTEGER ,
  FK_ENTITY           INTEGER ,
  IS_FROM_SERVER      INTEGER ,
  FOREIGN KEY   (FK_CUSTOMER_SURVEY) REFERENCES TBL_DM_CUSTOMER_SURVEY (_id)  ON DELETE CASCADE ,
  FOREIGN KEY   (FK_ENTITY)          REFERENCES TBL_DM_SURVEY_ENTITY          (_id)  ON DELETE CASCADE
);
CREATE index idx_TBL_DM_SURVEY_RELATION_ENTITY_INF                     ON TBL_DM_SURVEY_RELATION_ENTITY_INF (_id);
CREATE index idx_TBL_DM_SURVEY_RELATION_ENTITY_INF_FK_CUSTOMER_SURVEY  ON TBL_DM_SURVEY_RELATION_ENTITY_INF (FK_CUSTOMER_SURVEY);
CREATE index idx_TBL_DM_SURVEY_RELATION_ENTITY_INF_FK_ENTITY           ON TBL_DM_SURVEY_RELATION_ENTITY_INF (FK_ENTITY);

CREATE TABLE TBL_DM_SURVEY_RELATION_ENTITY_GROUP_INF(
  _id                 INTEGER PRIMARY KEY autoincrement ,
  FK_CUSTOMER_SURVEY  INTEGER ,
  FK_ENTITY_GROUP     INTEGER ,
  FOREIGN KEY   (FK_CUSTOMER_SURVEY) REFERENCES TBL_DM_CUSTOMER_SURVEY (_id)  ON DELETE CASCADE ,
  FOREIGN KEY   (FK_ENTITY_GROUP)    REFERENCES TBL_DM_SURVEY_ENTITY_GROUP    (_id)  ON DELETE CASCADE
);
CREATE index idx_TBL_DM_SURVEY_RELATION_ENTITY_GROUP_INF                     ON TBL_DM_SURVEY_RELATION_ENTITY_GROUP_INF (_id);
CREATE index idx_TBL_DM_SURVEY_RELATION_ENTITY_GROUP_INF_FK_CUSTOMER_SURVEY  ON TBL_DM_SURVEY_RELATION_ENTITY_GROUP_INF (FK_CUSTOMER_SURVEY);
CREATE index idx_TBL_DM_SURVEY_RELATION_FK_ENTITY_GROUP_INF_FK_ENTITY_GROUP  ON TBL_DM_SURVEY_RELATION_ENTITY_GROUP_INF (FK_ENTITY_GROUP);

CREATE TABLE TBL_DM_SURVEY_RELATION_FIELD_SPEC_INF(
  _id                 INTEGER PRIMARY KEY autoincrement ,
  FK_CUSTOMER_SURVEY  INTEGER ,
  FK_FIELD_SPEC     INTEGER ,
  FOREIGN KEY   (FK_CUSTOMER_SURVEY)  REFERENCES TBL_DM_CUSTOMER_SURVEY (_id)  ON DELETE CASCADE ,
  FOREIGN KEY   (FK_FIELD_SPEC)       REFERENCES TBL_DM_SURVEY_FIELD_SPEC      (_id)  ON DELETE CASCADE
);
CREATE index idx_TBL_DM_SURVEY_RELATION_FIELD_SPEC_INF                     ON TBL_DM_SURVEY_RELATION_FIELD_SPEC_INF (_id);
CREATE index idx_TBL_DM_SURVEY_RELATION_FIELD_SPEC_INF_FK_CUSTOMER_SURVEY  ON TBL_DM_SURVEY_RELATION_FIELD_SPEC_INF (FK_CUSTOMER_SURVEY);
CREATE index idx_TBL_DM_SURVEY_RELATION_FIELD_SPEC_INF_FK_FIELD_SPEC       ON TBL_DM_SURVEY_RELATION_FIELD_SPEC_INF (FK_FIELD_SPEC);

CREATE TABLE TBL_DM_FIELD_SPEC_RELATION_SURVEY_LOOKUP_INF(
  _id            INTEGER PRIMARY KEY autoincrement ,
  FK_FIELD_SPEC  INTEGER ,
  FK_LOOKUP      INTEGER ,
  FOREIGN KEY   (FK_FIELD_SPEC) REFERENCES TBL_DM_SURVEY_FIELD_SPEC (_id)  ON DELETE CASCADE ,
  FOREIGN KEY   (FK_LOOKUP)     REFERENCES TBL_DM_SURVEY_LOOKUP     (_id)  ON DELETE CASCADE
);
CREATE index idx_TBL_DM_FIELD_SPEC_RELATION_SURVEY_LOOKUP_INF                ON TBL_DM_FIELD_SPEC_RELATION_SURVEY_LOOKUP_INF (_id);
CREATE index idx_TBL_DM_FIELD_SPEC_RELATION_SURVEY_LOOKUP_INF_FK_FIELD_SPEC  ON TBL_DM_FIELD_SPEC_RELATION_SURVEY_LOOKUP_INF (FK_FIELD_SPEC);
CREATE index idx_TBL_DM_FIELD_SPEC_RELATION_SURVEY_LOOKUP_INF_FK_LOOKUP      ON TBL_DM_FIELD_SPEC_RELATION_SURVEY_LOOKUP_INF (FK_LOOKUP);

CREATE TABLE TBL_DM_SURVEY_INSTANCE(
  _id                 INTEGER PRIMARY KEY autoincrement,
  SRV_PK              INTEGER ,
  GUID                TEXT ,
  FK_TOUR_ITEM        INTEGER ,
  FK_CUSTOMER_SURVEY  INTEGER ,
  FK_CSMR             INTEGER ,
  FK_LOCATION         INTEGER ,
  FK_LKP_STATUS       INTEGER ,
  IS_DELETED          INTEGER NOT NULL DEFAULT 0,
  IS_PLANNED          INTEGER NOT NULL DEFAULT 0,
  OPERATION_DATE		  INTEGER NULL ,
  CREATE_DATE		      INTEGER NOT NULL DEFAULT (strftime('%s','now')*1000),
	CHANGE_DATE		      INTEGER NOT NULL DEFAULT (strftime('%s','now')*1000),
  FOREIGN KEY (FK_TOUR_ITEM)        REFERENCES TBL_DM_TOUR_ITEM (_id)           ON DELETE CASCADE ,
  FOREIGN KEY (FK_CUSTOMER_SURVEY)  REFERENCES TBL_DM_CUSTOMER_SURVEY (_id)     ON DELETE CASCADE ,
  FOREIGN KEY (FK_CSMR)         REFERENCES TBL_DM_CUSTOMER (_id)            ON DELETE CASCADE ,
  FOREIGN KEY (FK_LOCATION)         REFERENCES TBL_DM_LOCATION (_id)            ON DELETE CASCADE ,
  FOREIGN KEY (FK_LKP_STATUS)       REFERENCES TBL_GN_LOOKUP (_id)              ON DELETE CASCADE
);
CREATE index idx_TBL_DM_SURVEY_INTANCE                     ON TBL_DM_SURVEY_INSTANCE (_id);
CREATE index idx_TBL_DM_SURVEY_INTANCE_FK_TOUR_ITEM        ON TBL_DM_SURVEY_INSTANCE (FK_TOUR_ITEM);
CREATE index idx_TBL_DM_SURVEY_INTANCE_FK_CUSTOMER_SURVEY  ON TBL_DM_SURVEY_INSTANCE (FK_CUSTOMER_SURVEY);
CREATE index idx_TBL_DM_SURVEY_INTANCE_FK_CSMR         ON TBL_DM_SURVEY_INSTANCE (FK_CSMR);
CREATE index idx_TBL_DM_SURVEY_INTANCE_FK_LOCATION         ON TBL_DM_SURVEY_INSTANCE (FK_LOCATION);
CREATE index idx_TBL_DM_SURVEY_INTANCE_FK_LKP_STATUS       ON TBL_DM_SURVEY_INSTANCE (FK_LKP_STATUS);

INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES ('ارسال شده',      '0', 'CUSTOMER_SURVEY_STATUS_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES ('تکمیل شده',      '1', 'CUSTOMER_SURVEY_STATUS_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES ('در حال تکمیل',   '2', 'CUSTOMER_SURVEY_STATUS_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES ('تکمیل نشده',     '3', 'CUSTOMER_SURVEY_STATUS_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES ('نا مشخص',        '4', 'CUSTOMER_SURVEY_STATUS_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES ('اقدام به ارسال', '5', 'CUSTOMER_SURVEY_STATUS_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES ('اقدام به حذف',   '6', 'CUSTOMER_SURVEY_STATUS_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES ('ارسال با خطا',   '7', 'CUSTOMER_SURVEY_STATUS_TYPE');

ALTER TABLE TBL_DM_TRTM_ACT_UNEXEC_REASON_INF ADD COLUMN FK_SURVEY_INSTANCE INTEGER;

CREATE TABLE TBL_DM_SURVEY_INSTANCE_ENTITIES(
  _id                       INTEGER PRIMARY KEY autoincrement,
  FK_SURVEY_INST   INTEGER NOT NULL ,
  FK_ENTITY                 INTEGER ,
  IS_DYNAMIC                INTEGER NOT NULL DEFAULT 0,
  IS_DONE                   INTEGER NOT NULL DEFAULT 0,
  CREATE_DATE		            INTEGER NOT NULL DEFAULT (strftime('%s','now')*1000),
	CHANGE_DATE		            INTEGER NOT NULL DEFAULT (strftime('%s','now')*1000),
  FOREIGN KEY (FK_SURVEY_INST) REFERENCES TBL_DM_SURVEY_INSTANCE (_id) ON DELETE CASCADE ,
  FOREIGN KEY (FK_ENTITY)               REFERENCES TBL_DM_SURVEY_ENTITY (_id)                ON DELETE CASCADE
);
CREATE index idx_TBL_DM_SURVEY_INSTANCE_ENTITIES                         ON TBL_DM_SURVEY_INSTANCE_ENTITIES (_id);
CREATE index idx_TBL_DM_SURVEY_INSTANCE_ENTITIES_FK_SURVEY_INST ON TBL_DM_SURVEY_INSTANCE_ENTITIES (FK_SURVEY_INST);
CREATE index idx_TBL_DM_SURVEY_INSTANCE_ENTITIES_FK_ENTITY               ON TBL_DM_SURVEY_INSTANCE_ENTITIES (FK_ENTITY);

INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('فرم ارزیابی' ,'7','ACTIVITY_TYPE');

CREATE TABLE TBL_DM_SURVEY_FIELD_VALUES(
  _id                               INTEGER PRIMARY KEY autoincrement,
  FK_SURVEY_INST_ENTITY    INTEGER NOT NULL ,
  FK_FIELD_SPEC                     INTEGER NOT NULL ,
  FIELD_VALUE                       NONE ,
  FK_MEUN                           INTEGER ,
  CREATE_DATE		                    INTEGER NOT NULL DEFAULT (strftime('%s','now')*1000),
	CHANGE_DATE		                    INTEGER NOT NULL DEFAULT (strftime('%s','now')*1000),
  FOREIGN KEY (FK_SURVEY_INST_ENTITY)  REFERENCES TBL_DM_SURVEY_INSTANCE_ENTITIES (_id) ON DELETE CASCADE ,
  FOREIGN KEY (FK_FIELD_SPEC)                   REFERENCES TBL_DM_SURVEY_FIELD_SPEC        (_id) ON DELETE CASCADE ,
  FOREIGN KEY (FK_MEUN)                         REFERENCES TBL_DM_MEASUREMENT_UNIT     (_id) ON DELETE CASCADE
);
CREATE index idx_TBL_DM_SURVEY_FIELD_VALUES                                 ON TBL_DM_SURVEY_FIELD_VALUES (_id);
CREATE index idx_TBL_DM_SURVEY_FIELD_VALUES_FK_SURVEY_INST_ENTITY  ON TBL_DM_SURVEY_FIELD_VALUES (FK_SURVEY_INST_ENTITY);
CREATE index idx_TBL_DM_SURVEY_FIELD_VALUES_FK_FIELD_SPEC                   ON TBL_DM_SURVEY_FIELD_VALUES (FK_FIELD_SPEC);
CREATE index idx_TBL_DM_SURVEY_FIELD_VALUES_FK_MEUN                         ON TBL_DM_SURVEY_FIELD_VALUES (FK_MEUN);

