ALTER TABLE TBL_DM_CORPORATION ADD COLUMN HAS_CONTAINER_MODULE INTEGER DEFAULT 0;

ALTER TABLE TBL_DM_TOUR ADD COLUMN MAIN_BROKER_SRV_PK INTEGER DEFAULT 0;
ALTER TABLE TBL_DM_TOUR ADD COLUMN MAIN_BROKER_NAME TEXT DEFAULT NULL;

CREATE TABLE TBL_DM_CONTAINER (
	_id 				    INTEGER PRIMARY KEY AUTOINCREMENT,
	SRV_PK				    INTEGER NOT NULL,
	NAME				    TEXT,
	CODE 					TEXT,
	UNIT_SRV_PK				INTEGER NOT NULL,
	FEE						REAL NULL DEFAULT 0,
	MAIN_CONTAINER_SRV_PK	INTEGER,
	RATIO					INTEGER,
	IS_DELETED        		INTEGER NOT NULL DEFAULT 0,
	CREATE_DATE			  	INTEGER DEFAULT (strftime('%s','now')*1000),
	CHANGE_DATE			  	INTEGER DEFAULT (strftime('%s','now')*1000)
);

CREATE INDEX IDX_TBL_DM_CONTAINER_SRV_PK            ON TBL_DM_CONTAINER (SRV_PK);
CREATE INDEX IDX_TBL_DM_CONTAINER_ID   				ON TBL_DM_CONTAINER (_id);

CREATE TABLE TBL_DM_CONTAINER_DOC (
	_id 				    INTEGER PRIMARY KEY AUTOINCREMENT,
	SRV_PK				    INTEGER NULL,
	FK_CSMR 				INTEGER NOT NULL,
	FK_TIAC                 INTEGER NULL,
	FK_CRNCY 				INTEGER NOT NULL,
	FK_STORE 				INTEGER NULL,
	FK_LOCATION				INTEGER NULL,
	FK_LKP_STATUS 			INTEGER NULL,
	FK_SRV_ERR 				INTEGER NULL,
	GUID 					TEXT NULL UNIQUE ON CONFLICT FAIL,
	FK_USRSLOF_REGISTRANT   INTEGER NOT NULL,
	OPERATION_DATE			INTEGER NULL,
	REGISTER_DATE 			INTEGER NOT NULL DEFAULT (strftime('%s','now') * 1000),
	NET_PRICE 			    REAL NOT NULL DEFAULT 0,
	DESCRIPTION           	TEXT,
	NUMBER 					TEXT NULL,
	COUNTER_PART_NAME		TEXT,
	COUNTER_PART_SRV_PK		TEXT,
	CREATE_DATE			  	INTEGER DEFAULT (strftime('%s','now')*1000),
    CHANGE_DATE			  	INTEGER DEFAULT (strftime('%s','now')*1000),
	IS_LATEST_DOC			INTEGER NOT NULL DEFAULT 0,
	IS_DELIVERY_DOC 		INTEGER NOT NULL DEFAULT 0,
	IS_RETURN_DOC			INTEGER NOT NULL DEFAULT 0,
	FOREIGN KEY( FK_CSMR )              REFERENCES TBL_DM_CUSTOMER ( _id ) ON DELETE CASCADE ,
	FOREIGN KEY( FK_TIAC )              REFERENCES TBL_DM_TOUR_ITEM_ACTIVITY ( _id ) ON DELETE CASCADE,
	FOREIGN KEY( FK_CRNCY )             REFERENCES TBL_DM_CURRENCY ( _id ) ,
	FOREIGN KEY (FK_STORE)              REFERENCES TBL_DM_STORE (_id),
	FOREIGN KEY (FK_LOCATION)           REFERENCES TBL_DM_LOCATION (_id) ON DELETE CASCADE,
	FOREIGN KEY (FK_USRSLOF_REGISTRANT) REFERENCES TBL_DM_USER_SALE_OFFICE_INF (_id),
	FOREIGN KEY( FK_LKP_STATUS )        REFERENCES TBL_GN_LOOKUP ( _id )
);

CREATE INDEX IDX_DM_CONTAINER_DOC_SRV_PK 		ON TBL_DM_CONTAINER_DOC (SRV_PK);
CREATE INDEX IDX_DM_CONTAINER_DOC_ID 			ON TBL_DM_CONTAINER_DOC (_id);

CREATE TABLE TBL_DM_CONTAINER_DOC_ITEM (
	_id 				    INTEGER PRIMARY KEY AUTOINCREMENT,
	SRV_PK				    INTEGER NULL,
	FK_CONTAINER_DOC		INTEGER NOT NULL,
	PRIORITY 				INTEGER NULL,
	QUANTITY 				REAL NOT NULL,
	REMAINING               REAL NULL,
	FK_CONTAINER 			INTEGER NOT NULL,
	DESCRIPTION 			TEXT NULL,
	FEE 					REAL NOT NULL DEFAULT 0,
	FK_CONTAINER_DOC_ITEM	INTEGER,
	NET_PRICE 				REAL NOT NULL DEFAULT 0,
	CREATE_DATE			  	INTEGER DEFAULT (strftime('%s','now')*1000),
	CHANGE_DATE			  	INTEGER DEFAULT (strftime('%s','now')*1000),
	FOREIGN KEY( FK_CONTAINER_DOC ) references TBL_DM_CONTAINER_DOC ( _id ) ON DELETE CASCADE,
	FOREIGN KEY( FK_CONTAINER ) references TBL_DM_CONTAINER ( _id ),
	FOREIGN KEY( FK_CONTAINER_DOC_ITEM ) references TBL_DM_CONTAINER_DOC_ITEM ( _id )
);

CREATE INDEX IDX_DM_CONTAINER_DOC_ITEM_SRV_PK 		ON TBL_DM_CONTAINER_DOC_ITEM (SRV_PK);
CREATE INDEX IDX_DM_CONTAINER_DOC_ITEM_ID 			ON TBL_DM_CONTAINER_DOC_ITEM (_id);

INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('تحویل امانی' ,'8','ACTIVITY_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('برگشت امانی' ,'9','ACTIVITY_TYPE');



