CREATE TABLE TBL_DM_PRODUCT_GROUP (
	_id 				    INTEGER PRIMARY KEY AUTOINCREMENT,
	SRV_PK				    INTEGER NULL,
	NAME				    TEXT
	);

CREATE TABLE TBL_DM_PRDT_PRODUCT_GROUP (
	_id 				    INTEGER PRIMARY KEY AUTOINCREMENT,
	FK_PRODUCT_GROUP	    INTEGER NOT NULL,
	FK_PRODUCT				INTEGER NOT NULL,
	IS_DELETED        		INTEGER NOT NULL DEFAULT 0,
	FOREIGN KEY (FK_PRODUCT_GROUP) REFERENCES TBL_DM_PRODUCT_GROUP (_id) ON DELETE CASCADE,
	FOREIGN KEY (FK_PRODUCT) REFERENCES TBL_DM_PRODUCT (_id) ON DELETE CASCADE
	);

CREATE TABLE TBL_DM_PRODUCT_PACK (
	_id 				    INTEGER PRIMARY KEY AUTOINCREMENT,
	SRV_PK				    INTEGER NULL,
	NAME				    TEXT,
	NUMBER 					TEXT,
	IS_DELETED        		INTEGER NOT NULL DEFAULT 0,
	CAN_DETERMINE_QUANTITY	INTEGER NOT NULL DEFAULT 0,
	CREATE_DATE			  	INTEGER DEFAULT (strftime('%s','now')*1000),
	CHANGE_DATE			  	INTEGER DEFAULT (strftime('%s','now')*1000)
	);

CREATE TABLE TBL_DM_PRDT_ITEM_PRODUCT_PACK (
	_id 				            INTEGER PRIMARY KEY AUTOINCREMENT,
	SRV_PK				            INTEGER NULL,
	FK_PRODUCT_PACK		            INTEGER NOT NULL,
	FK_MEASUREMENT_UNIT             INTEGER NOT NULL,
	FK_PRODUCT                      INTEGER NULL,
	QUANTITY 				        TEXT,
	FK_TRACKING_FACTOR_COLLECTION   INTEGER NULL,
	FK_PRODUCT_GROUP                INTEGER NULL,
	IS_DELETED        		        INTEGER NOT NULL DEFAULT 0,
	FOREIGN KEY (FK_PRODUCT_PACK) REFERENCES TBL_DM_PRODUCT_PACK (_id) ON DELETE CASCADE,
	FOREIGN KEY (FK_MEASUREMENT_UNIT) REFERENCES TBL_DM_MEASUREMENT_UNIT (_id) ON DELETE CASCADE,
	FOREIGN KEY (FK_PRODUCT) REFERENCES TBL_DM_PRODUCT (_id) ON DELETE CASCADE,
	FOREIGN KEY (FK_TRACKING_FACTOR_COLLECTION) REFERENCES TBL_DM_TRACKING_FACTOR_COLLECTION (_id) ON DELETE CASCADE,
	FOREIGN KEY (FK_PRODUCT_GROUP) REFERENCES TBL_DM_PRODUCT_GROUP (_id) ON DELETE CASCADE
	);

CREATE TABLE TBL_DM_COLD_DEFINITIVE_INVOICE_ITEM_Backup (
	_id 								    INTEGER PRIMARY KEY AUTOINCREMENT,
	SRV_PK								    INTEGER NOT NULL,
    ITEM_INDEX							    INTEGER NOT NULL,
    FK_COLD_DEFINITIVE_INVOICE     	        INTEGER NOT NULL,
    FK_PRODUCT		      	        	    INTEGER NOT NULL,
    FK_LKP_TYPE                             INTEGER NOT NULL,
    QUANTITY			      			    REAL NOT NULL,
    FK_PRDT_MEUN							INTEGER NOT NULL,
    DESCRIPTION							    TEXT,
	FK_SLAR								    INTEGER NOT NULL,
    FEE									    REAL NOT NULL,
    PRICE								    REAL NOT NULL,
	NET_PRICE							    REAL NOT NULL,
    ADDITION_AMOUNT						    REAL NOT NULL,
    REDUCTION_AMOUNT					    REAL NOT NULL,
    PARENT_ITEM_INDEX					    INTEGER,
    FK_SLPLCY_FREE_PRODUCT_POLICY		    INTEGER,
    FREE_PRODUCT_CONDITION_ROW_ID		    INTEGER,
    CREATE_DATE							    INTEGER DEFAULT (strftime('%s','now')*1000) NOT NULL,
    CHANGE_DATE							    INTEGER DEFAULT (strftime('%s','now')*1000) NOT NULL,
	SETTLEMENT_PERIOD 						TEXT,
	FK_TRACKING_FACTOR_COLLECTION   		INTEGER NULL,
    FOREIGN KEY (FK_COLD_DEFINITIVE_INVOICE) REFERENCES TBL_DM_COLD_DEFINITIVE_INVOICE (_id) ON DELETE CASCADE,
    FOREIGN KEY (FK_PRODUCT) REFERENCES TBL_DM_PRODUCT (_id),
    FOREIGN KEY (FK_LKP_TYPE) REFERENCES TBL_GN_LOOKUP (_id),
    FOREIGN KEY (FK_PRDT_MEUN) REFERENCES TBL_DM_PRDT_MEUN_INF (_id),
    FOREIGN KEY (FK_SLAR) REFERENCES TBL_DM_SALES_AREA (_id),
    FOREIGN KEY (FK_SLPLCY_FREE_PRODUCT_POLICY) REFERENCES TBL_DM_SALES_POLICY (_id),
	FOREIGN KEY (FK_TRACKING_FACTOR_COLLECTION) REFERENCES TBL_DM_TRACKING_FACTOR_COLLECTION (_id)
	);
INSERT INTO TBL_DM_COLD_DEFINITIVE_INVOICE_ITEM_Backup SELECT 
	_id,SRV_PK,ITEM_INDEX,FK_COLD_DEFINITIVE_INVOICE,FK_PRODUCT,FK_LKP_TYPE,
    QUANTITY,FK_PRDT_MEUN,DESCRIPTION,FK_SLAR,FEE,PRICE,NET_PRICE,ADDITION_AMOUNT,
    REDUCTION_AMOUNT,PARENT_ITEM_INDEX,FK_SLPLCY_FREE_PRODUCT_POLICY,FREE_PRODUCT_CONDITION_ROW_ID,
    CREATE_DATE,CHANGE_DATE,SETTLEMENT_PERIOD,FK_TRACKING_FACTOR_COLLECTION
FROM TBL_DM_COLD_DEFINITIVE_INVOICE_ITEM;
DROP TABLE  TBL_DM_COLD_DEFINITIVE_INVOICE_ITEM;

CREATE TABLE TBL_DM_COLD_DEFINITIVE_INVOICE_ITEM (
	_id 								    INTEGER PRIMARY KEY AUTOINCREMENT,
	SRV_PK								    INTEGER NOT NULL,
    ITEM_INDEX							    INTEGER NOT NULL,
    FK_COLD_DEFINITIVE_INVOICE     	        INTEGER NOT NULL,
    FK_PRODUCT		      	        	    INTEGER NOT NULL,
    FK_LKP_TYPE                             INTEGER NOT NULL,
    QUANTITY			      			    REAL NOT NULL,
    FK_PRDT_MEUN							INTEGER NOT NULL,
    DESCRIPTION							    TEXT,
	FK_SLAR								    INTEGER NOT NULL,
    FEE									    REAL NOT NULL,
    PRICE								    REAL NOT NULL,
	NET_PRICE							    REAL NOT NULL,
    ADDITION_AMOUNT						    REAL NOT NULL,
    REDUCTION_AMOUNT					    REAL NOT NULL,
    PARENT_ITEM_INDEX					    INTEGER,
    FK_SLPLCY_FREE_PRODUCT_POLICY		    INTEGER,
    FREE_PRODUCT_CONDITION_ROW_ID		    INTEGER,
    CREATE_DATE							    INTEGER DEFAULT (strftime('%s','now')*1000) NOT NULL,
    CHANGE_DATE							    INTEGER DEFAULT (strftime('%s','now')*1000) NOT NULL,
	SETTLEMENT_PERIOD 						TEXT,
	FK_TRACKING_FACTOR_COLLECTION   		INTEGER NULL,
	FK_PRODUCT_PACK                         INTEGER NULL,
	FK_PRODUCT_PACK_ITEM                    INTEGER NULL,
	PRODUCT_PACK_QUANTITY                   INTEGER NULL,
    FOREIGN KEY (FK_COLD_DEFINITIVE_INVOICE) REFERENCES TBL_DM_COLD_DEFINITIVE_INVOICE (_id) ON DELETE CASCADE,
    FOREIGN KEY (FK_PRODUCT) REFERENCES TBL_DM_PRODUCT (_id),
    FOREIGN KEY (FK_LKP_TYPE) REFERENCES TBL_GN_LOOKUP (_id),
    FOREIGN KEY (FK_PRDT_MEUN) REFERENCES TBL_DM_PRDT_MEUN_INF (_id),
    FOREIGN KEY (FK_SLAR) REFERENCES TBL_DM_SALES_AREA (_id),
    FOREIGN KEY (FK_SLPLCY_FREE_PRODUCT_POLICY) REFERENCES TBL_DM_SALES_POLICY (_id),
	FOREIGN KEY (FK_TRACKING_FACTOR_COLLECTION) REFERENCES TBL_DM_TRACKING_FACTOR_COLLECTION (_id),
	FOREIGN KEY (FK_PRODUCT_PACK) REFERENCES TBL_DM_PRODUCT_PACK (_id),
	FOREIGN KEY (FK_PRODUCT_PACK_ITEM) REFERENCES TBL_DM_PRDT_ITEM_PRODUCT_PACK (_id)
	);
INSERT INTO TBL_DM_COLD_DEFINITIVE_INVOICE_ITEM 
	(_id,SRV_PK,ITEM_INDEX,FK_COLD_DEFINITIVE_INVOICE,FK_PRODUCT,FK_LKP_TYPE,
    QUANTITY,FK_PRDT_MEUN,DESCRIPTION,FK_SLAR,FEE,PRICE,NET_PRICE,ADDITION_AMOUNT,
    REDUCTION_AMOUNT,PARENT_ITEM_INDEX,FK_SLPLCY_FREE_PRODUCT_POLICY,FREE_PRODUCT_CONDITION_ROW_ID,
    CREATE_DATE,CHANGE_DATE,SETTLEMENT_PERIOD,FK_TRACKING_FACTOR_COLLECTION)
SELECT
	_id,SRV_PK,ITEM_INDEX,FK_COLD_DEFINITIVE_INVOICE,FK_PRODUCT,FK_LKP_TYPE,
    QUANTITY,FK_PRDT_MEUN,DESCRIPTION,FK_SLAR,FEE,PRICE,NET_PRICE,ADDITION_AMOUNT,
    REDUCTION_AMOUNT,PARENT_ITEM_INDEX,FK_SLPLCY_FREE_PRODUCT_POLICY,FREE_PRODUCT_CONDITION_ROW_ID,
    CREATE_DATE,CHANGE_DATE,SETTLEMENT_PERIOD,FK_TRACKING_FACTOR_COLLECTION
FROM TBL_DM_COLD_DEFINITIVE_INVOICE_ITEM_Backup;
DROP TABLE  TBL_DM_COLD_DEFINITIVE_INVOICE_ITEM_Backup;

CREATE TABLE TBL_DM_COLD_NON_DEFINITIVE_INVOICE_ITEM_Backup (
    _id 							        INTEGER PRIMARY KEY AUTOINCREMENT,
    FK_COLD_NON_DEFINITIVE_INVOICE 	        INTEGER NOT NULL,
	FK_SALES_ASSIGNMENT_ITEM 		        INTEGER NULL,
	PRIORITY 						        INTEGER NOT NULL,
	IS_DELETED 						        INTEGER NOT NULL DEFAULT 0,
	QUANTITY 						        REAL NOT NULL,
	FK_PRDT_MEUN 					        INTEGER NOT NULL,
	FK_SLAR 						        INTEGER NOT NULL,
	DESCRIPTION 					        TEXT NULL,
	FEE 							        REAL NOT NULL DEFAULT 0,
	PRICE 							        REAL NOT NULL DEFAULT 0,
	NET_PRICE 						        REAL NOT NULL DEFAULT 0,
	ADDITION_AMOUNT 				        REAL NOT NULL DEFAULT 0,
	REDUCTION_AMOUNT 				        REAL NOT NULL DEFAULT 0,
	FK_INVOICE_ITEM_PARENT 			        INTEGER NULL,
	FK_SLPLCY_FREE_PRODUCT_POLICY 	        INTEGER NULL,
	FREE_PRODUCT_CONDITION_ROW_ID 	        INTEGER,
	CREATE_DATE 					        INTEGER NOT NULL DEFAULT (strftime('%s','now') * 1000),
	CHANGE_DATE 					        INTEGER NOT NULL DEFAULT (strftime('%s','now') * 1000),
	FK_LKP_TYPE                             INTEGER NOT NULL DEFAULT 1 REFERENCES TBL_GN_LOOKUP (_id),
	SETTLEMENT_PERIOD                       TEXT,
	FOREIGN KEY (FK_COLD_NON_DEFINITIVE_INVOICE) REFERENCES TBL_DM_COLD_NON_DEFINITIVE_INVOICE (_id) ON DELETE CASCADE,
	FOREIGN KEY (FK_SALES_ASSIGNMENT_ITEM) REFERENCES TBL_DM_SALES_ASSIGNMENT_ITEM (_id) ON DELETE CASCADE,
	FOREIGN KEY (FK_PRDT_MEUN) REFERENCES TBL_DM_PRDT_MEUN_INF (_id),
	FOREIGN KEY (FK_SLAR) REFERENCES TBL_DM_SALES_AREA (_id),
	FOREIGN KEY (FK_INVOICE_ITEM_PARENT) REFERENCES TBL_DM_COLD_NON_DEFINITIVE_INVOICE_ITEM (_id),
	FOREIGN KEY (FK_SLPLCY_FREE_PRODUCT_POLICY) REFERENCES TBL_DM_SALES_POLICY (_id)
	);
INSERT INTO TBL_DM_COLD_NON_DEFINITIVE_INVOICE_ITEM_Backup SELECT
	_id,FK_COLD_NON_DEFINITIVE_INVOICE,FK_SALES_ASSIGNMENT_ITEM,PRIORITY,IS_DELETED,
	QUANTITY,FK_PRDT_MEUN,FK_SLAR,DESCRIPTION,FEE,PRICE,NET_PRICE,ADDITION_AMOUNT,
	REDUCTION_AMOUNT,FK_INVOICE_ITEM_PARENT,FK_SLPLCY_FREE_PRODUCT_POLICY,
	FREE_PRODUCT_CONDITION_ROW_ID,CREATE_DATE,CHANGE_DATE,FK_LKP_TYPE,SETTLEMENT_PERIOD
FROM TBL_DM_COLD_NON_DEFINITIVE_INVOICE_ITEM;
DROP TABLE  TBL_DM_COLD_NON_DEFINITIVE_INVOICE_ITEM;

CREATE TABLE TBL_DM_COLD_NON_DEFINITIVE_INVOICE_ITEM (
    _id 							        INTEGER PRIMARY KEY AUTOINCREMENT,
    FK_COLD_NON_DEFINITIVE_INVOICE 	        INTEGER NOT NULL,
	FK_SALES_ASSIGNMENT_ITEM 		        INTEGER NULL,
	PRIORITY 						        INTEGER NOT NULL,
	IS_DELETED 						        INTEGER NOT NULL DEFAULT 0,
	QUANTITY 						        REAL NOT NULL,
	FK_PRDT_MEUN 					        INTEGER NOT NULL,
	FK_SLAR 						        INTEGER NOT NULL,
	DESCRIPTION 					        TEXT NULL,
	FEE 							        REAL NOT NULL DEFAULT 0,
	PRICE 							        REAL NOT NULL DEFAULT 0,
	NET_PRICE 						        REAL NOT NULL DEFAULT 0,
	ADDITION_AMOUNT 				        REAL NOT NULL DEFAULT 0,
	REDUCTION_AMOUNT 				        REAL NOT NULL DEFAULT 0,
	FK_INVOICE_ITEM_PARENT 			        INTEGER NULL,
	FK_SLPLCY_FREE_PRODUCT_POLICY 	        INTEGER NULL,
	FREE_PRODUCT_CONDITION_ROW_ID 	        INTEGER,
	CREATE_DATE 					        INTEGER NOT NULL DEFAULT (strftime('%s','now') * 1000),
	CHANGE_DATE 					        INTEGER NOT NULL DEFAULT (strftime('%s','now') * 1000),
	FK_LKP_TYPE                             INTEGER NOT NULL DEFAULT 1 REFERENCES TBL_GN_LOOKUP (_id),
	SETTLEMENT_PERIOD                       TEXT,
	FK_PRODUCT_PACK                         INTEGER NULL,
	FK_PRODUCT_PACK_ITEM                    INTEGER NULL,
	PRODUCT_PACK_QUANTITY                   INTEGER NULL,
	FOREIGN KEY (FK_COLD_NON_DEFINITIVE_INVOICE) REFERENCES TBL_DM_COLD_NON_DEFINITIVE_INVOICE (_id) ON DELETE CASCADE,
	FOREIGN KEY (FK_SALES_ASSIGNMENT_ITEM) REFERENCES TBL_DM_SALES_ASSIGNMENT_ITEM (_id) ON DELETE CASCADE,
	FOREIGN KEY (FK_PRDT_MEUN) REFERENCES TBL_DM_PRDT_MEUN_INF (_id),
	FOREIGN KEY (FK_SLAR) REFERENCES TBL_DM_SALES_AREA (_id),
	FOREIGN KEY (FK_INVOICE_ITEM_PARENT) REFERENCES TBL_DM_COLD_NON_DEFINITIVE_INVOICE_ITEM (_id),
	FOREIGN KEY (FK_SLPLCY_FREE_PRODUCT_POLICY) REFERENCES TBL_DM_SALES_POLICY (_id),
	FOREIGN KEY (FK_PRODUCT_PACK) REFERENCES TBL_DM_PRODUCT_PACK (_id),
	FOREIGN KEY (FK_PRODUCT_PACK_ITEM) REFERENCES TBL_DM_PRDT_ITEM_PRODUCT_PACK (_id)
	);
INSERT INTO TBL_DM_COLD_NON_DEFINITIVE_INVOICE_ITEM 
	(_id,FK_COLD_NON_DEFINITIVE_INVOICE,FK_SALES_ASSIGNMENT_ITEM,PRIORITY,IS_DELETED,
	QUANTITY,FK_PRDT_MEUN,FK_SLAR,DESCRIPTION,FEE,PRICE,NET_PRICE,ADDITION_AMOUNT,
	REDUCTION_AMOUNT,FK_INVOICE_ITEM_PARENT,FK_SLPLCY_FREE_PRODUCT_POLICY,
	FREE_PRODUCT_CONDITION_ROW_ID,CREATE_DATE,CHANGE_DATE,FK_LKP_TYPE,SETTLEMENT_PERIOD)
SELECT
	_id,FK_COLD_NON_DEFINITIVE_INVOICE,FK_SALES_ASSIGNMENT_ITEM,PRIORITY,IS_DELETED,
	QUANTITY,FK_PRDT_MEUN,FK_SLAR,DESCRIPTION,FEE,PRICE,NET_PRICE,ADDITION_AMOUNT,
	REDUCTION_AMOUNT,FK_INVOICE_ITEM_PARENT,FK_SLPLCY_FREE_PRODUCT_POLICY,
	FREE_PRODUCT_CONDITION_ROW_ID,CREATE_DATE,CHANGE_DATE,FK_LKP_TYPE,SETTLEMENT_PERIOD
FROM TBL_DM_COLD_NON_DEFINITIVE_INVOICE_ITEM_Backup;
DROP TABLE  TBL_DM_COLD_NON_DEFINITIVE_INVOICE_ITEM_Backup;

CREATE TABLE TBL_DM_HOT_SALES_INVOICE_ITEM_Backup (
    _id                                     INTEGER PRIMARY KEY AUTOINCREMENT,
    FK_HSI_INVOICE                          INTEGER NOT NULL,
    PRIORITY                                INTEGER NOT NULL,
    IS_DELETED                              INTEGER NOT NULL DEFAULT 0,
    CREATE_DATE                             INTEGER NOT NULL DEFAULT (strftime('%s','now') * 1000),
    CHANGE_DATE                             INTEGER NOT NULL DEFAULT (strftime('%s','now') * 1000),
    QUANTITY                                REAL NOT NULL,
    FK_PRDT_MEUN                            INTEGER NOT NULL,
    FK_SLAR                                 INTEGER NOT NULL,
    DESCRIPTION                             TEXT NULL,
    FEE                                     REAL NOT NULL DEFAULT 0,
    PRICE                                   REAL NOT NULL DEFAULT 0,
    NET_PRICE                               REAL NOT NULL DEFAULT 0,
    ADDITION_AMOUNT                         REAL NOT NULL DEFAULT 0,
    REDUCTION_AMOUNT                        REAL NOT NULL DEFAULT 0,
    FK_INVOICE_ITEM_PARENT                  INTEGER NULL,
    FK_SLPLCY_FREE_PRODUCT_POLICY           INTEGER NULL,
    FREE_PRODUCT_CONDITION_ROW_ID           INTEGER,
    FK_LKP_TYPE                             INTEGER NOT NULL DEFAULT 1 REFERENCES TBL_GN_LOOKUP (_id),
    SETTLEMENT_PERIOD                       TEXT,
    FOREIGN KEY( FK_HSI_INVOICE ) REFERENCES TBL_DM_HOT_SALES_INVOICE ( _id ) ON DELETE CASCADE,
	FOREIGN KEY( FK_PRDT_MEUN ) REFERENCES TBL_DM_PRDT_MEUN_INF ( _id ),
    FOREIGN KEY( FK_SLAR ) REFERENCES TBL_DM_SALES_AREA ( _id ) ,
	FOREIGN KEY( FK_INVOICE_ITEM_PARENT ) REFERENCES TBL_DM_HOT_SALES_INVOICE_ITEM ( _id ),
    FOREIGN KEY( FK_SLPLCY_FREE_PRODUCT_POLICY ) REFERENCES TBL_DM_SALES_POLICY ( _id )
    );
INSERT INTO TBL_DM_HOT_SALES_INVOICE_ITEM_Backup SELECT
	_id,FK_HSI_INVOICE,PRIORITY,IS_DELETED,CREATE_DATE,CHANGE_DATE,QUANTITY,FK_PRDT_MEUN,
    FK_SLAR,DESCRIPTION,FEE,PRICE,NET_PRICE,ADDITION_AMOUNT,REDUCTION_AMOUNT,FK_INVOICE_ITEM_PARENT,
    FK_SLPLCY_FREE_PRODUCT_POLICY,FREE_PRODUCT_CONDITION_ROW_ID,FK_LKP_TYPE,SETTLEMENT_PERIOD
FROM TBL_DM_HOT_SALES_INVOICE_ITEM;
DROP TABLE TBL_DM_HOT_SALES_INVOICE_ITEM;

CREATE TABLE TBL_DM_HOT_SALES_INVOICE_ITEM (
    _id                                     INTEGER PRIMARY KEY AUTOINCREMENT,
    FK_HSI_INVOICE                          INTEGER NOT NULL,
    PRIORITY                                INTEGER NOT NULL,
    IS_DELETED                              INTEGER NOT NULL DEFAULT 0,
    CREATE_DATE                             INTEGER NOT NULL DEFAULT (strftime('%s','now') * 1000),
    CHANGE_DATE                             INTEGER NOT NULL DEFAULT (strftime('%s','now') * 1000),
    QUANTITY                                REAL NOT NULL,
    FK_PRDT_MEUN                            INTEGER NOT NULL,
    FK_SLAR                                 INTEGER NOT NULL,
    DESCRIPTION                             TEXT NULL,
    FEE                                     REAL NOT NULL DEFAULT 0,
    PRICE                                   REAL NOT NULL DEFAULT 0,
    NET_PRICE                               REAL NOT NULL DEFAULT 0,
    ADDITION_AMOUNT                         REAL NOT NULL DEFAULT 0,
    REDUCTION_AMOUNT                        REAL NOT NULL DEFAULT 0,
    FK_INVOICE_ITEM_PARENT                  INTEGER NULL,
    FK_SLPLCY_FREE_PRODUCT_POLICY           INTEGER NULL,
    FREE_PRODUCT_CONDITION_ROW_ID           INTEGER,
    FK_LKP_TYPE                             INTEGER NOT NULL DEFAULT 1 REFERENCES TBL_GN_LOOKUP (_id),
    SETTLEMENT_PERIOD                       TEXT,
	FK_PRODUCT_PACK                         INTEGER NULL,
	FK_PRODUCT_PACK_ITEM                    INTEGER NULL,
	PRODUCT_PACK_QUANTITY                   INTEGER NULL,
    FOREIGN KEY( FK_HSI_INVOICE ) REFERENCES TBL_DM_HOT_SALES_INVOICE ( _id ) ON DELETE CASCADE,
	FOREIGN KEY( FK_PRDT_MEUN ) REFERENCES TBL_DM_PRDT_MEUN_INF ( _id ),
    FOREIGN KEY( FK_SLAR ) REFERENCES TBL_DM_SALES_AREA ( _id ) ,
	FOREIGN KEY( FK_INVOICE_ITEM_PARENT ) REFERENCES TBL_DM_HOT_SALES_INVOICE_ITEM ( _id ),
    FOREIGN KEY( FK_SLPLCY_FREE_PRODUCT_POLICY ) REFERENCES TBL_DM_SALES_POLICY ( _id ),
	FOREIGN KEY (FK_PRODUCT_PACK) REFERENCES TBL_DM_PRODUCT_PACK (_id),
	FOREIGN KEY (FK_PRODUCT_PACK_ITEM) REFERENCES TBL_DM_PRDT_ITEM_PRODUCT_PACK (_id)
    );
INSERT INTO TBL_DM_HOT_SALES_INVOICE_ITEM
	(_id,FK_HSI_INVOICE,PRIORITY,IS_DELETED,CREATE_DATE,CHANGE_DATE,QUANTITY,FK_PRDT_MEUN,
    FK_SLAR,DESCRIPTION,FEE,PRICE,NET_PRICE,ADDITION_AMOUNT,REDUCTION_AMOUNT,FK_INVOICE_ITEM_PARENT,
    FK_SLPLCY_FREE_PRODUCT_POLICY,FREE_PRODUCT_CONDITION_ROW_ID,FK_LKP_TYPE,SETTLEMENT_PERIOD)
SELECT
	_id,FK_HSI_INVOICE,PRIORITY,IS_DELETED,CREATE_DATE,CHANGE_DATE,QUANTITY,FK_PRDT_MEUN,
    FK_SLAR,DESCRIPTION,FEE,PRICE,NET_PRICE,ADDITION_AMOUNT,REDUCTION_AMOUNT,FK_INVOICE_ITEM_PARENT,
    FK_SLPLCY_FREE_PRODUCT_POLICY,FREE_PRODUCT_CONDITION_ROW_ID,FK_LKP_TYPE,SETTLEMENT_PERIOD
FROM TBL_DM_HOT_SALES_INVOICE_ITEM_Backup;
DROP TABLE TBL_DM_HOT_SALES_INVOICE_ITEM_Backup;

CREATE TABLE TBL_DM_ORDER_ITEM_Backup (
	_id                                     INTEGER PRIMARY KEY AUTOINCREMENT,
	QUANTITY                                REAL NOT NULL,
	FK_ORDER                                INTEGER NOT NULL,
	FK_PRDT_MEUN                            INTEGER NOT NULL,
	FK_PRODUCT_INVENTORY                    INTEGER NULL,
	PRIORITY                                INTEGER NOT NULL,
	IS_DELETED                              INTEGER NOT NULL DEFAULT 0,
	CREATE_DATE                             INTEGER NOT NULL DEFAULT (strftime('%s','now') * 1000),
	CHANGE_DATE                             INTEGER NOT NULL DEFAULT (strftime('%s','now') * 1000),
	FEE                                     REAL NOT NULL DEFAULT 0,
	FREE_PRODUCT_CONDITION_ROW_ID           INTEGER,
	PRICE                                   REAL NOT NULL DEFAULT 0,
	NET_PRICE                               REAL NOT NULL DEFAULT 0,
	ADDITION_AMOUNT                         REAL NOT NULL DEFAULT 0,
	REDUCTION_AMOUNT                        REAL NOT NULL DEFAULT 0,
	DESCRIPTION                             TEXT NULL,
	FK_SLAR                                 INTEGER,
	FK_ORDER_ITEM_PARENT                    INTEGER NULL,
	FK_SLPLCY_FREE_PRODUCT_POLICY           INTEGER NULL,
	FK_LKP_TYPE                             INTEGER NOT NULL DEFAULT 1 REFERENCES TBL_GN_LOOKUP (_id),
	SETTLEMENT_PERIOD                       TEXT,
	FOREIGN KEY (FK_ORDER) REFERENCES TBL_DM_ORDER (_id) ON DELETE CASCADE,
	FOREIGN KEY (FK_PRDT_MEUN) REFERENCES TBL_DM_PRDT_MEUN_INF (_id),
	FOREIGN KEY (FK_SLAR) REFERENCES TBL_DM_SALES_AREA (_id),
	FOREIGN KEY (FK_ORDER_ITEM_PARENT) REFERENCES TBL_DM_ORDER_ITEM (_id),
	FOREIGN KEY (FK_SLPLCY_FREE_PRODUCT_POLICY) REFERENCES TBL_DM_SALES_POLICY (_id),
	FOREIGN KEY (FK_PRODUCT_INVENTORY) REFERENCES TBL_DM_PRODUCT_INVENTORY (_id)
	);
INSERT INTO TBL_DM_ORDER_ITEM_Backup SELECT
	_id,QUANTITY,FK_ORDER,FK_PRDT_MEUN,FK_PRODUCT_INVENTORY,PRIORITY,IS_DELETED,
	CREATE_DATE,CHANGE_DATE,FEE,FREE_PRODUCT_CONDITION_ROW_ID,PRICE,NET_PRICE,
	ADDITION_AMOUNT,REDUCTION_AMOUNT,DESCRIPTION,FK_SLAR,FK_ORDER_ITEM_PARENT,
	FK_SLPLCY_FREE_PRODUCT_POLICY,FK_LKP_TYPE,SETTLEMENT_PERIOD
FROM TBL_DM_ORDER_ITEM;
DROP TABLE TBL_DM_ORDER_ITEM;

CREATE TABLE TBL_DM_ORDER_ITEM (
	_id                                     INTEGER PRIMARY KEY AUTOINCREMENT,
	QUANTITY                                REAL NOT NULL,
	FK_ORDER                                INTEGER NOT NULL,
	FK_PRDT_MEUN                            INTEGER NOT NULL,
	FK_PRODUCT_INVENTORY                    INTEGER NULL,
	PRIORITY                                INTEGER NOT NULL,
	IS_DELETED                              INTEGER NOT NULL DEFAULT 0,
	CREATE_DATE                             INTEGER NOT NULL DEFAULT (strftime('%s','now') * 1000),
	CHANGE_DATE                             INTEGER NOT NULL DEFAULT (strftime('%s','now') * 1000),
	FEE                                     REAL NOT NULL DEFAULT 0,
	FREE_PRODUCT_CONDITION_ROW_ID           INTEGER,
	PRICE                                   REAL NOT NULL DEFAULT 0,
	NET_PRICE                               REAL NOT NULL DEFAULT 0,
	ADDITION_AMOUNT                         REAL NOT NULL DEFAULT 0,
	REDUCTION_AMOUNT                        REAL NOT NULL DEFAULT 0,
	DESCRIPTION                             TEXT NULL,
	FK_SLAR                                 INTEGER,
	FK_ORDER_ITEM_PARENT                    INTEGER NULL,
	FK_SLPLCY_FREE_PRODUCT_POLICY           INTEGER NULL,
	FK_LKP_TYPE                             INTEGER NOT NULL DEFAULT 1 REFERENCES TBL_GN_LOOKUP (_id),
	SETTLEMENT_PERIOD                       TEXT,
	FK_PRODUCT_PACK                         INTEGER NULL,
	FK_PRODUCT_PACK_ITEM                    INTEGER NULL,
	PRODUCT_PACK_QUANTITY                   INTEGER NULL,
	FOREIGN KEY (FK_ORDER) REFERENCES TBL_DM_ORDER (_id) ON DELETE CASCADE,
	FOREIGN KEY (FK_PRDT_MEUN) REFERENCES TBL_DM_PRDT_MEUN_INF (_id),
	FOREIGN KEY (FK_SLAR) REFERENCES TBL_DM_SALES_AREA (_id),
	FOREIGN KEY (FK_ORDER_ITEM_PARENT) REFERENCES TBL_DM_ORDER_ITEM (_id),
	FOREIGN KEY (FK_SLPLCY_FREE_PRODUCT_POLICY) REFERENCES TBL_DM_SALES_POLICY (_id),
	FOREIGN KEY (FK_PRODUCT_INVENTORY) REFERENCES TBL_DM_PRODUCT_INVENTORY (_id),
	FOREIGN KEY (FK_PRODUCT_PACK) REFERENCES TBL_DM_PRODUCT_PACK (_id),
	FOREIGN KEY (FK_PRODUCT_PACK_ITEM) REFERENCES TBL_DM_PRDT_ITEM_PRODUCT_PACK (_id)
	);
INSERT INTO TBL_DM_ORDER_ITEM 
	(_id,QUANTITY,FK_ORDER,FK_PRDT_MEUN,FK_PRODUCT_INVENTORY,PRIORITY,IS_DELETED,
	CREATE_DATE,CHANGE_DATE,FEE,FREE_PRODUCT_CONDITION_ROW_ID,PRICE,NET_PRICE,
	ADDITION_AMOUNT,REDUCTION_AMOUNT,DESCRIPTION,FK_SLAR,FK_ORDER_ITEM_PARENT,
	FK_SLPLCY_FREE_PRODUCT_POLICY,FK_LKP_TYPE,SETTLEMENT_PERIOD)
SELECT
	_id,QUANTITY,FK_ORDER,FK_PRDT_MEUN,FK_PRODUCT_INVENTORY,PRIORITY,IS_DELETED,
	CREATE_DATE,CHANGE_DATE,FEE,FREE_PRODUCT_CONDITION_ROW_ID,PRICE,NET_PRICE,
	ADDITION_AMOUNT,REDUCTION_AMOUNT,DESCRIPTION,FK_SLAR,FK_ORDER_ITEM_PARENT,
	FK_SLPLCY_FREE_PRODUCT_POLICY,FK_LKP_TYPE,SETTLEMENT_PERIOD
FROM TBL_DM_ORDER_ITEM_Backup;
DROP TABLE TBL_DM_ORDER_ITEM_Backup;	

CREATE TABLE TBL_DM_SALES_ASSIGNMENT_ITEM_Backup (
	_id 								    INTEGER PRIMARY KEY AUTOINCREMENT,
	SRV_PK								    INTEGER NOT NULL,
	ITEM_INDEX							    INTEGER NOT NULL,
	FK_SALES_ASSIGNMENT		      	        INTEGER NOT NULL,
	FK_PRODUCT		      	        	    INTEGER NOT NULL,
	FK_MEUN								    INTEGER NOT NULL,
	QUANTITY			      			    REAL NOT NULL,
	DESCRIPTION							    TEXT,
	FK_SLAR								    INTEGER NOT NULL,
	FK_LKP_TYPE                             INTEGER NOT NULL DEFAULT 1,
	FEE									    REAL NOT NULL,
	PRICE								    REAL NOT NULL,
	NET_PRICE							    REAL NOT NULL,
	ADDITION_AMOUNT						    REAL NOT NULL,
	REDUCTION_AMOUNT					    REAL NOT NULL,
	PARENT_ITEM_INDEX					    INTEGER,
	FK_SLPLCY_FREE_PRODUCT_POLICY		    INTEGER,
	FREE_PRODUCT_CONDITION_ROW_ID		    INTEGER,
	CREATE_DATE							    INTEGER DEFAULT (strftime('%s','now')*1000) NOT NULL,
	CHANGE_DATE							    INTEGER DEFAULT (strftime('%s','now')*1000) NOT NULL,
	FK_TRACKING_FACTOR_COLLECTION   		INTEGER NULL,
	FOREIGN KEY (FK_SALES_ASSIGNMENT) REFERENCES TBL_DM_SALES_ASSIGNMENT (_id) ON DELETE CASCADE,
	FOREIGN KEY (FK_PRODUCT) REFERENCES TBL_DM_PRODUCT (_id),
	FOREIGN KEY (FK_MEUN) REFERENCES TBL_DM_MEASUREMENT_UNIT (_id),
	FOREIGN KEY (FK_SLAR) REFERENCES TBL_DM_SALES_AREA (_id),
	FOREIGN KEY (FK_LKP_TYPE) REFERENCES TBL_GN_LOOKUP (_id),
	FOREIGN KEY (FK_SLPLCY_FREE_PRODUCT_POLICY) REFERENCES TBL_DM_SALES_POLICY (_id)
	FOREIGN KEY (FK_TRACKING_FACTOR_COLLECTION) REFERENCES TBL_DM_TRACKING_FACTOR_COLLECTION (_id)
);
INSERT INTO TBL_DM_SALES_ASSIGNMENT_ITEM_Backup SELECT
	_id,SRV_PK,ITEM_INDEX,FK_SALES_ASSIGNMENT,FK_PRODUCT,FK_MEUN,QUANTITY,DESCRIPTION,
	FK_SLAR,FK_LKP_TYPE,FEE,PRICE,NET_PRICE,ADDITION_AMOUNT,REDUCTION_AMOUNT,PARENT_ITEM_INDEX,
	FK_SLPLCY_FREE_PRODUCT_POLICY,FREE_PRODUCT_CONDITION_ROW_ID,CREATE_DATE,CHANGE_DATE,
	FK_TRACKING_FACTOR_COLLECTION
FROM TBL_DM_SALES_ASSIGNMENT_ITEM;
DROP TABLE TBL_DM_SALES_ASSIGNMENT_ITEM;

CREATE TABLE TBL_DM_SALES_ASSIGNMENT_ITEM (
	_id 								    INTEGER PRIMARY KEY AUTOINCREMENT,
	SRV_PK								    INTEGER NOT NULL,
	ITEM_INDEX							    INTEGER NOT NULL,
	FK_SALES_ASSIGNMENT		      	        INTEGER NOT NULL,
	FK_PRODUCT		      	        	    INTEGER NOT NULL,
	FK_MEUN								    INTEGER NOT NULL,
	QUANTITY			      			    REAL NOT NULL,
	DESCRIPTION							    TEXT,
	FK_SLAR								    INTEGER NOT NULL,
	FK_LKP_TYPE                             INTEGER NOT NULL DEFAULT 1,
	FEE									    REAL NOT NULL,
	PRICE								    REAL NOT NULL,
	NET_PRICE							    REAL NOT NULL,
	ADDITION_AMOUNT						    REAL NOT NULL,
	REDUCTION_AMOUNT					    REAL NOT NULL,
	PARENT_ITEM_INDEX					    INTEGER,
	FK_SLPLCY_FREE_PRODUCT_POLICY		    INTEGER,
	FREE_PRODUCT_CONDITION_ROW_ID		    INTEGER,
	CREATE_DATE							    INTEGER DEFAULT (strftime('%s','now')*1000) NOT NULL,
	CHANGE_DATE							    INTEGER DEFAULT (strftime('%s','now')*1000) NOT NULL,
	FK_TRACKING_FACTOR_COLLECTION   		INTEGER NULL,	
	FK_PRODUCT_PACK                         INTEGER NULL,
	FK_PRODUCT_PACK_ITEM                    INTEGER NULL,
	PRODUCT_PACK_QUANTITY                   INTEGER NULL,
	FOREIGN KEY (FK_SALES_ASSIGNMENT) REFERENCES TBL_DM_SALES_ASSIGNMENT (_id) ON DELETE CASCADE,
	FOREIGN KEY (FK_PRODUCT) REFERENCES TBL_DM_PRODUCT (_id),
	FOREIGN KEY (FK_MEUN) REFERENCES TBL_DM_MEASUREMENT_UNIT (_id),
	FOREIGN KEY (FK_SLAR) REFERENCES TBL_DM_SALES_AREA (_id),
	FOREIGN KEY (FK_LKP_TYPE) REFERENCES TBL_GN_LOOKUP (_id),
	FOREIGN KEY (FK_SLPLCY_FREE_PRODUCT_POLICY) REFERENCES TBL_DM_SALES_POLICY (_id)
	FOREIGN KEY (FK_TRACKING_FACTOR_COLLECTION) REFERENCES TBL_DM_TRACKING_FACTOR_COLLECTION (_id),
	FOREIGN KEY (FK_PRODUCT_PACK) REFERENCES TBL_DM_PRODUCT_PACK (_id),
	FOREIGN KEY (FK_PRODUCT_PACK_ITEM) REFERENCES TBL_DM_PRDT_ITEM_PRODUCT_PACK (_id)
);
INSERT INTO TBL_DM_SALES_ASSIGNMENT_ITEM 
	(_id,SRV_PK,ITEM_INDEX,FK_SALES_ASSIGNMENT,FK_PRODUCT,FK_MEUN,QUANTITY,DESCRIPTION,
	FK_SLAR,FK_LKP_TYPE,FEE,PRICE,NET_PRICE,ADDITION_AMOUNT,REDUCTION_AMOUNT,PARENT_ITEM_INDEX,
	FK_SLPLCY_FREE_PRODUCT_POLICY,FREE_PRODUCT_CONDITION_ROW_ID,CREATE_DATE,CHANGE_DATE,
	FK_TRACKING_FACTOR_COLLECTION)
SELECT
	_id,SRV_PK,ITEM_INDEX,FK_SALES_ASSIGNMENT,FK_PRODUCT,FK_MEUN,QUANTITY,DESCRIPTION,
	FK_SLAR,FK_LKP_TYPE,FEE,PRICE,NET_PRICE,ADDITION_AMOUNT,REDUCTION_AMOUNT,PARENT_ITEM_INDEX,
	FK_SLPLCY_FREE_PRODUCT_POLICY,FREE_PRODUCT_CONDITION_ROW_ID,CREATE_DATE,CHANGE_DATE,
	FK_TRACKING_FACTOR_COLLECTION
FROM TBL_DM_SALES_ASSIGNMENT_ITEM_Backup;
DROP TABLE TBL_DM_SALES_ASSIGNMENT_ITEM_Backup; 	

