CREATE TABLE TBL_DM_LATEST_INVOICES_INFO_Backup (
	_id 						integer primary key autoincrement,
	FK_CUSTOMER					integer not null,
	SRV_PK						integer not null unique ON CONFLICT fail,
	CREATE_ORDER_DATE			integer null,
	ORDER_NUMBER				integer null,
	PAYMENT_AGREEMENT_ID		integer null,
	PAYMENT_AGREEMENT_NAME		text null,
	NET_PRICE					real null,
	REDUCTION_AMOUNT			real null,
	SETTLED_AMOUNT				real null,
	CURRENCY_ID					integer null,
	CREATE_DATE					integer default (strftime('%s','now')*1000),
	CHANGE_DATE					integer default (strftime('%s','now')*1000),
	FK_SLTP                     integer null references TBL_DM_SALES_TYPE (_id),
	FK_LKP_PAYER_TYPE           integer not null default -1 references TBL_GN_LOOKUP (_id),
	FK_SLACC_ACCOUNT            integer not null default -1 references TBL_DM_SALES_ACCOUNT (_id),
	EMPLOYEE_SRV_PK             integer not null default -1,
	EMPLOYEE_NAME               TEXT not null default '',
	IS_RETURN_INVOICE           integer not null default 0,
	RECEIVABLE_AMOUNT           REAL NULL,
	SETTLEMENT_DATE             INTEGER NULL,
	SETTLEMENT_PERIOD           INTEGER NULL,
	FK_LKP_STATE                INTEGER NOT NULL DEFAULT 0,
	foreign key(FK_CUSTOMER) references TBL_DM_CUSTOMER (_id) ON DELETE CASCADE
);

INSERT INTO TBL_DM_LATEST_INVOICES_INFO_Backup
    select _id, FK_CUSTOMER, SRV_PK, CREATE_ORDER_DATE, ORDER_NUMBER, PAYMENT_AGREEMENT_ID,
    PAYMENT_AGREEMENT_NAME, NET_PRICE, REDUCTION_AMOUNT, SETTLED_AMOUNT, CURRENCY_ID,
    CREATE_DATE, CHANGE_DATE, FK_SLTP, FK_LKP_PAYER_TYPE, FK_SLACC_ACCOUNT, EMPLOYEE_SRV_PK,
    EMPLOYEE_NAME, IS_RETURN_INVOICE, RECEIVABLE_AMOUNT, SETTLEMENT_DATE, SETTLEMENT_PERIOD, FK_LKP_STATE
    from TBL_DM_LATEST_INVOICES_INFO;

DROP TABLE  TBL_DM_LATEST_INVOICES_INFO;

CREATE TABLE TBL_DM_LATEST_INVOICES_INFO (
	_id 						integer primary key autoincrement,
	FK_CUSTOMER					integer not null,
	SRV_PK						integer not null unique ON CONFLICT fail,
	CREATE_ORDER_DATE			integer null,
	ORDER_NUMBER				integer null,
	PAYMENT_AGREEMENT_ID		integer null,
	PAYMENT_AGREEMENT_NAME		text null,
	NET_PRICE					real null,
	REDUCTION_AMOUNT			real null,
	SETTLED_AMOUNT				real null,
	CURRENCY_ID					integer null,
	CREATE_DATE					integer default (strftime('%s','now')*1000),
	CHANGE_DATE					integer default (strftime('%s','now')*1000),
	FK_SLTP                     integer null references TBL_DM_SALES_TYPE (_id),
	FK_LKP_PAYER_TYPE           integer not null default -1 references TBL_GN_LOOKUP (_id),
	FK_SLACC_ACCOUNT            integer not null default -1 references TBL_DM_SALES_ACCOUNT (_id),
	EMPLOYEE_SRV_PK             integer not null default -1,
	EMPLOYEE_NAME               TEXT not null default '',
	IS_RETURN_INVOICE           integer not null default 0,
	RECEIVABLE_AMOUNT           REAL NULL,
	SETTLEMENT_DATE             INTEGER NULL,
	SETTLEMENT_PERIOD           INTEGER NULL,
	FK_LKP_STATE                INTEGER NOT NULL DEFAULT 0,
	foreign key(FK_CUSTOMER) references TBL_DM_CUSTOMER (_id) ON DELETE CASCADE
);

INSERT INTO TBL_DM_LATEST_INVOICES_INFO
    select _id, FK_CUSTOMER, SRV_PK, CREATE_ORDER_DATE, ORDER_NUMBER, PAYMENT_AGREEMENT_ID,
    PAYMENT_AGREEMENT_NAME, NET_PRICE, REDUCTION_AMOUNT, SETTLED_AMOUNT, CURRENCY_ID,
    CREATE_DATE, CHANGE_DATE, FK_SLTP, FK_LKP_PAYER_TYPE, FK_SLACC_ACCOUNT, EMPLOYEE_SRV_PK,
    EMPLOYEE_NAME, IS_RETURN_INVOICE, RECEIVABLE_AMOUNT, SETTLEMENT_DATE, SETTLEMENT_PERIOD, FK_LKP_STATE
    from TBL_DM_LATEST_INVOICES_INFO_Backup;

DROP TABLE  TBL_DM_LATEST_INVOICES_INFO_Backup;


CREATE INDEX idx_TBL_DM_LATEST_INVOICES_INFO_CURRENCY_ID on TBL_DM_LATEST_INVOICES_INFO (CURRENCY_ID);

CREATE INDEX idx_TBL_DM_LATEST_INVOICES_INFO_PAYMENT_AGREEMENT_ID on TBL_DM_LATEST_INVOICES_INFO (PAYMENT_AGREEMENT_ID);

CREATE INDEX idx_TBL_DM_LATEST_INVOICES_INFO_SRV_PK on TBL_DM_LATEST_INVOICES_INFO (SRV_PK);

CREATE INDEX idx_TBL_DM_LATEST_INVOICES_INFO_FK_CUSTOMER on TBL_DM_LATEST_INVOICES_INFO (FK_CUSTOMER);

CREATE INDEX idx_TBL_DM_LATEST_INVOICES_INFO_PAYMENT_AGREEMENT_NAME on TBL_DM_LATEST_INVOICES_INFO (PAYMENT_AGREEMENT_NAME);