CREATE TABLE TBL_DM_MAIN_BROKER (
    _id                     INTEGER PRIMARY KEY AUTOINCREMENT,
    SRV_PK                  INTEGER NOT NULL,
    NAME                    TEXT    NOT NULL,
    CODE                    TEXT    NOT NULL,
    IS_DISTRIBUTION_AGENT   INTEGER NOT NULL,
    IS_HOT_SELLER           INTEGER NOT NULL,
    IS_COLLECTOR            INTEGER NOT NULL,
    IS_VISITOR              INTEGER NOT NULL,
    CREATE_DATE             INTEGER NOT NULL DEFAULT (strftime('%s', 'now') * 1000),
    CHANGE_DATE             INTEGER NOT NULL DEFAULT (strftime('%s', 'now') * 1000)
);

create index idx_TBL_DM_MAIN_BROKER_SRV_PK on TBL_DM_MAIN_BROKER (SRV_PK);

CREATE TABLE TBL_DM_MAIN_BROKER_TOUR_INF (
    _id                     INTEGER PRIMARY KEY AUTOINCREMENT,
    FK_MAIN_BROKER          INTEGER NOT NULL,
    FK_TOUR                 INTEGER NULL,
    CREATE_DATE             INTEGER NOT NULL DEFAULT (strftime('%s', 'now') * 1000),
    CHANGE_DATE             INTEGER NOT NULL DEFAULT (strftime('%s', 'now') * 1000),

    foreign key (FK_MAIN_BROKER) REFERENCES TBL_DM_MAIN_BROKER (_id) ON DELETE CASCADE,
    foreign key (FK_TOUR) REFERENCES TBL_DM_TOUR (_id) ON DELETE CASCADE
);

create index idx_TBL_DM_MAIN_BROKER_TOUR_INF_FK_MAIN_BROKER on TBL_DM_MAIN_BROKER_TOUR_INF (FK_MAIN_BROKER);
create index idx_TBL_DM_MAIN_BROKER_TOUR_INF_FK_TOUR on TBL_DM_MAIN_BROKER_TOUR_INF (FK_TOUR);

ALTER TABLE TBL_DM_DISTRIBUTION_ASSIGNMENT ADD COLUMN FK_MAIN_BROKER INTEGER NULL REFERENCES TBL_DM_MAIN_BROKER (_id);
create index idx_TBL_DM_DISTRIBUTION_ASSIGNMENT_FK_MAIN_BROKER on TBL_DM_DISTRIBUTION_ASSIGNMENT (FK_MAIN_BROKER);
update TBL_DM_DISTRIBUTION_ASSIGNMENT set FK_MAIN_BROKER =
    (select broker._id from TBL_DM_MAIN_BROKER broker
     join TBL_GN_USER user on (broker.SRV_PK = user.SRV_PK)
     join TBL_DM_USER_SALE_OFFICE_INF usrslof on (user._id = usrslof.FK_USR)
     join TBL_DM_TOUR tour on (tour._id = TBL_DM_DISTRIBUTION_ASSIGNMENT.FK_TOUR)
     where usrslof._id = tour.FK_USRSLOF_RESPONSIBLE);

ALTER TABLE TBL_DM_USRSLOF_CSMR_INF ADD COLUMN BROKER_IDS TEXT NULL DEFAULT NULL;

insert into TBL_DM_MAIN_BROKER (SRV_PK, NAME, CODE, IS_DISTRIBUTION_AGENT, IS_HOT_SELLER, IS_COLLECTOR, IS_VISITOR)
    select SRV_PK, NAME, CODE, IS_DISTRIBUTION_AGENT, IS_HOT_SELLER, IS_COLLECTOR, IS_VISITOR
        from TBL_GN_USER;

insert into TBL_DM_MAIN_BROKER_TOUR_INF (FK_MAIN_BROKER, FK_TOUR)
    select _id, NULL from TBL_GN_USER;

ALTER TABLE TBL_DM_ORDER ADD COLUMN FK_MAIN_BROKER INTEGER NULL REFERENCES TBL_DM_MAIN_BROKER (_id);
create index idx_TBL_DM_ORDER_FK_MAIN_BROKER on TBL_DM_ORDER (FK_MAIN_BROKER);
update TBL_DM_ORDER set FK_MAIN_BROKER =
    (select broker._id from TBL_DM_MAIN_BROKER broker
     join TBL_GN_USER user on (broker.SRV_PK = user.SRV_PK)
     join TBL_DM_USER_SALE_OFFICE_INF usrslof on (user._id = usrslof.FK_USR)
     where usrslof._id = TBL_DM_ORDER.FK_USRSLOF_REGISTRANT);

ALTER TABLE TBL_DM_HOT_SALES_INVOICE ADD COLUMN FK_MAIN_BROKER INTEGER NULL REFERENCES TBL_DM_MAIN_BROKER (_id);
create index idx_TBL_DM_HOT_SALES_INVOICE_FK_MAIN_BROKER on TBL_DM_HOT_SALES_INVOICE (FK_MAIN_BROKER);
update TBL_DM_HOT_SALES_INVOICE set FK_MAIN_BROKER =
    (select broker._id from TBL_DM_MAIN_BROKER broker
     join TBL_GN_USER user on (broker.SRV_PK = user.SRV_PK)
     join TBL_DM_USER_SALE_OFFICE_INF usrslof on (user._id = usrslof.FK_USR)
     where usrslof._id = TBL_DM_HOT_SALES_INVOICE.FK_USRSLOF_REGISTRANT);

ALTER TABLE TBL_DM_COLD_DEFINITIVE_INVOICE ADD COLUMN FK_MAIN_BROKER INTEGER NULL REFERENCES TBL_DM_MAIN_BROKER (_id);
create index idx_TBL_DM_COLD_DEFINITIVE_INVOICE_FK_MAIN_BROKER on TBL_DM_COLD_DEFINITIVE_INVOICE (FK_MAIN_BROKER);
update TBL_DM_COLD_DEFINITIVE_INVOICE set FK_MAIN_BROKER =
    (select broker._id from TBL_DM_MAIN_BROKER broker
     join TBL_GN_USER user on (broker.SRV_PK = user.SRV_PK)
     join TBL_DM_USER_SALE_OFFICE_INF usrslof on (user._id = usrslof.FK_USR)
     where usrslof._id = TBL_DM_COLD_DEFINITIVE_INVOICE.FK_USRSLOF_REGISTRANT);

ALTER TABLE TBL_DM_COLD_NON_DEFINITIVE_INVOICE ADD COLUMN FK_MAIN_BROKER INTEGER NULL REFERENCES TBL_DM_MAIN_BROKER (_id);
create index idx_TBL_DM_COLD_NON_DEFINITIVE_INVOICE_FK_MAIN_BROKER on TBL_DM_COLD_NON_DEFINITIVE_INVOICE (FK_MAIN_BROKER);
update TBL_DM_COLD_NON_DEFINITIVE_INVOICE set FK_MAIN_BROKER =
    (select broker._id from TBL_DM_MAIN_BROKER broker
     join TBL_GN_USER user on (broker.SRV_PK = user.SRV_PK)
     join TBL_DM_USER_SALE_OFFICE_INF usrslof on (user._id = usrslof.FK_USR)
     where usrslof._id = TBL_DM_COLD_NON_DEFINITIVE_INVOICE.FK_USRSLOF_REGISTRANT);

ALTER TABLE TBL_DM_SALES_ASSIGNMENT ADD COLUMN FK_MAIN_BROKER INTEGER NULL REFERENCES TBL_DM_MAIN_BROKER (_id);
create index idx_TBL_DM_SALES_ASSIGNMENT_FK_MAIN_BROKER on TBL_DM_SALES_ASSIGNMENT (FK_MAIN_BROKER);
update TBL_DM_SALES_ASSIGNMENT set FK_MAIN_BROKER =
    (select broker._id from TBL_DM_MAIN_BROKER broker
     join TBL_GN_USER user on (broker.SRV_PK = user.SRV_PK)
     join TBL_DM_USER_SALE_OFFICE_INF usrslof on (user._id = usrslof.FK_USR)
     where usrslof._id = TBL_DM_SALES_ASSIGNMENT.FK_USRSLOF_REGISTRANT);

ALTER TABLE TBL_DM_RETURN_INVOICE ADD COLUMN FK_MAIN_BROKER INTEGER NULL REFERENCES TBL_DM_MAIN_BROKER (_id);
create index idx_TBL_DM_RETURN_INVOICE_FK_MAIN_BROKER on TBL_DM_RETURN_INVOICE (FK_MAIN_BROKER);
update TBL_DM_RETURN_INVOICE set FK_MAIN_BROKER =
    (select broker._id from TBL_DM_MAIN_BROKER broker
     join TBL_GN_USER user on (broker.SRV_PK = user.SRV_PK)
     join TBL_DM_USER_SALE_OFFICE_INF usrslof on (user._id = usrslof.FK_USR)
     where usrslof._id = TBL_DM_RETURN_INVOICE.FK_USRSLOF_REGISTRANT);

ALTER TABLE TBL_DM_RETURN_PERMIT ADD COLUMN FK_MAIN_BROKER INTEGER NULL REFERENCES TBL_DM_MAIN_BROKER (_id);
create index idx_TBL_DM_RETURN_PERMIT_FK_MAIN_BROKER on TBL_DM_RETURN_PERMIT (FK_MAIN_BROKER);
update TBL_DM_RETURN_PERMIT set FK_MAIN_BROKER =
    (select broker._id from TBL_DM_MAIN_BROKER broker
     join TBL_GN_USER user on (broker.SRV_PK = user.SRV_PK)
     join TBL_DM_USER_SALE_OFFICE_INF usrslof on (user._id = usrslof.FK_USR)
     where usrslof._id = TBL_DM_RETURN_PERMIT.FK_USRSLOF_REGISTRANT);

ALTER TABLE TBL_DM_RETURN_PERMIT_REQUEST ADD COLUMN FK_MAIN_BROKER INTEGER NULL REFERENCES TBL_DM_MAIN_BROKER (_id);
create index idx_TBL_DM_RETURN_PERMIT_REQUEST_FK_MAIN_BROKER on TBL_DM_RETURN_PERMIT_REQUEST (FK_MAIN_BROKER);
update TBL_DM_RETURN_PERMIT_REQUEST set FK_MAIN_BROKER =
    (select broker._id from TBL_DM_MAIN_BROKER broker
     join TBL_GN_USER user on (broker.SRV_PK = user.SRV_PK)
     join TBL_DM_USER_SALE_OFFICE_INF usrslof on (user._id = usrslof.FK_USR)
     where usrslof._id = TBL_DM_RETURN_PERMIT_REQUEST.FK_USRSLOF_REGISTRANT);

ALTER TABLE TBL_DM_CONTAINER_DOC ADD COLUMN FK_MAIN_BROKER INTEGER NULL REFERENCES TBL_DM_MAIN_BROKER (_id);
create index idx_TBL_DM_CONTAINER_DOC_FK_MAIN_BROKER on TBL_DM_CONTAINER_DOC (FK_MAIN_BROKER);
update TBL_DM_CONTAINER_DOC set FK_MAIN_BROKER =
    (select broker._id from TBL_DM_MAIN_BROKER broker
     join TBL_GN_USER user on (broker.SRV_PK = user.SRV_PK)
     join TBL_DM_USER_SALE_OFFICE_INF usrslof on (user._id = usrslof.FK_USR)
     where usrslof._id = TBL_DM_CONTAINER_DOC.FK_USRSLOF_REGISTRANT);

ALTER TABLE TBL_DM_VEHICLE_REPOSITORY_DELIVERY_PRODUCT ADD COLUMN FK_MAIN_BROKER INTEGER NULL REFERENCES TBL_DM_MAIN_BROKER (_id);
create index idx_TBL_DM_VEHICLE_REPOSITORY_DELIVERY_PRODUCT_FK_MAIN_BROKER on TBL_DM_VEHICLE_REPOSITORY_DELIVERY_PRODUCT (FK_MAIN_BROKER);
update TBL_DM_VEHICLE_REPOSITORY_DELIVERY_PRODUCT set FK_MAIN_BROKER =
    (select broker._id from TBL_DM_MAIN_BROKER broker
     join TBL_GN_USER user on (broker.SRV_PK = user.SRV_PK)
     join TBL_DM_USER_SALE_OFFICE_INF usrslof on (user._id = usrslof.FK_USR)
     join TBL_DM_VEHICLE_REPOSITORY_DELIVERY delivery on (delivery._id = TBL_DM_VEHICLE_REPOSITORY_DELIVERY_PRODUCT.FK_VEHICLE_REPOSITORY_DELIVERY)
     join TBL_DM_TOUR tour on (tour._id = delivery.FK_TOUR)
     where usrslof._id = tour.FK_USRSLOF_RESPONSIBLE);

ALTER TABLE TBL_DM_VEHICLE_REPOSITORY_DELIVERY_CONTAINER ADD COLUMN FK_MAIN_BROKER INTEGER NULL REFERENCES TBL_DM_MAIN_BROKER (_id);
create index idx_TBL_DM_VEHICLE_REPOSITORY_DELIVERY_CONTAINER_FK_MAIN_BROKER on TBL_DM_VEHICLE_REPOSITORY_DELIVERY_CONTAINER (FK_MAIN_BROKER);
update TBL_DM_VEHICLE_REPOSITORY_DELIVERY_CONTAINER set FK_MAIN_BROKER =
    (select broker._id from TBL_DM_MAIN_BROKER broker
     join TBL_GN_USER user on (broker.SRV_PK = user.SRV_PK)
     join TBL_DM_USER_SALE_OFFICE_INF usrslof on (user._id = usrslof.FK_USR)
     join TBL_DM_VEHICLE_REPOSITORY_DELIVERY delivery on (delivery._id = TBL_DM_VEHICLE_REPOSITORY_DELIVERY_CONTAINER.FK_VEHICLE_REPOSITORY_DELIVERY)
     join TBL_DM_TOUR tour on (tour._id = delivery.FK_TOUR)
     where usrslof._id = tour.FK_USRSLOF_RESPONSIBLE);

