CREATE TABLE TBL_DM_ORDER_ASSIGNMENT (
    _id integer primary key autoincrement,
    SRV_PK	integer not null,
    FK_DIST_ASSIGNMENT integer not null,
    DATE integer,
    FK_TOUR_ITEM integer not null,
    FK_CSMR integer not null,
    FK_ADRS integer,
    FK_PAYAGR integer,
    FK_SLAR integer,
    FK_TIAC integer,
    FK_USRSLOF_REGISTRANT integer not null,
    FK_LKP_STATUS integer not null,
    FK_SLACC_ACCOUNT integer null,
    SALES_EMPLOYEE_NAME	  text,
    IS_DELETED integer not null default 0 ,
    CREATE_DATE integer not null default (strftime('%s','now') * 1000),
    CHANGE_DATE integer not null default (strftime('%s','now') * 1000),
    GUID text not null unique ON CONFLICT fail,
    PRICE real not null default 0,
    NET_PRICE real not null default 0,
    ADDITION_AMOUNT real not null default 0,
    REDUCTION_AMOUNT real not null default 0,
    DESCRIPTION text null,
    FK_CRNCY integer not null,
    FK_LOCATION integer null,
    FK_SLTP integer not null,
    FK_LKP_PAYER_TYPE integer not null,
    FK_SRV_ERR integer null,
    FK_PLANT integer,
    NUMBER text null,
    REGISTER_DATE integer null,
    IS_PRINTED integer not null default 0 ,
    FK_STORE integer null references TBL_DM_STORE (_id),
    OPERATION_DATE integer null,
    SETTLEMENT_PERIOD TEXT,
    SETTLEMENT_PERIOD_STATUS INTEGER,
    FK_DISTRIBUTION_SHIFT INTEGER,
    DISTRIBUTION_DATE INTEGER,
    IS_SHARED INTEGER NOT NULL DEFAULT 0,
    FK_ALTERNATIVE_VISITOR INTEGER,
    FK_LKP_DEVICE_MOBILE_DATA_STATE integer null references TBL_GN_LOOKUP (_id),
    FK_MAIN_BROKER INTEGER NULL REFERENCES TBL_DM_MAIN_BROKER (_id),
    VISITOR_CUSTOMER_ID integer null,
    VISITOR_BRAND_ID integer NULL,
    foreign key( FK_TIAC ) references TBL_DM_TOUR_ITEM_ACTIVITY ( _id ) ON DELETE CASCADE,
    foreign key (FK_TOUR_ITEM) references TBL_DM_TOUR_ITEM (_id) ON DELETE CASCADE,
    foreign key( FK_SLACC_ACCOUNT ) references TBL_DM_SALES_ACCOUNT ( _id ) ,
    foreign key (FK_DIST_ASSIGNMENT) references TBL_DM_DISTRIBUTION_ASSIGNMENT (_id) ,
    foreign key( FK_CSMR ) references TBL_DM_CUSTOMER ( _id ) ON DELETE CASCADE ,
    foreign key( FK_ADRS ) references TBL_DM_ADDRESS ( _id ) ,
    foreign key( FK_PAYAGR ) references TBL_DM_PAYMENT_AGREEMENT ( _id ) ,
    foreign key( FK_SLAR ) references TBL_DM_SALES_AREA ( _id ) ,
    foreign key( FK_USRSLOF_REGISTRANT ) references TBL_DM_USER_SALE_OFFICE_INF ( _id ) ,
    foreign key( FK_CRNCY ) references TBL_DM_CURRENCY ( _id ) ,
    foreign key( FK_LOCATION ) references TBL_DM_LOCATION ( _id ) ON DELETE CASCADE,
    foreign key( FK_LKP_PAYER_TYPE ) references TBL_GN_LOOKUP ( _id ) ,
    foreign key( FK_PLANT ) references TBL_DM_PLANTS ( _id ) ,
    foreign key( FK_SRV_ERR ) references TBL_DM_ERROR_MESSAGE ( _id ) ,
    foreign key( FK_LKP_STATUS ) references TBL_GN_LOOKUP ( _id )
);

CREATE INDEX idx_TBL_DM_ORDER_ASSIGNMENT_FK_MAIN_BROKER on TBL_DM_ORDER_ASSIGNMENT (FK_MAIN_BROKER);

CREATE INDEX idx_TBL_DM_ORDER_ASSIGNMENT_FK_ALTERNATIVE_VISITOR on TBL_DM_ORDER_ASSIGNMENT (FK_ALTERNATIVE_VISITOR);

CREATE INDEX idx_TBL_DM_ORDER_ASSIGNMENT_VISITOR_CUSTOMER_ID on TBL_DM_ORDER_ASSIGNMENT (VISITOR_CUSTOMER_ID);

INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('توزیع نشده' ,'1','ORDER_ASSIGNMENT_STATUS_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('تحویل شده' ,'2','ORDER_ASSIGNMENT_STATUS_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('عدم تحویل' ,'3','ORDER_ASSIGNMENT_STATUS_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('تحویل موقت' ,'4','ORDER_ASSIGNMENT_STATUS_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('تحویل شده ناقص' ,'5', 'ORDER_ASSIGNMENT_STATUS_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('تحویل موقت ناقص' ,'6', 'ORDER_ASSIGNMENT_STATUS_TYPE');

INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) values('ابطال درخواست فروش', '1', 'ORDER_ASSIGNMENT_FAIL_ACTION_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) values('توزیع مجدد درخواست فروش', '2', 'ORDER_ASSIGNMENT_FAIL_ACTION_TYPE');
INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) values('بستن درخواست فروش', '3', 'ORDER_ASSIGNMENT_FAIL_ACTION_TYPE');

CREATE TABLE TBL_DM_ORDER_ASSIGNMENT_ITEM (
	_id                                     INTEGER PRIMARY KEY AUTOINCREMENT,
	SRV_PK					                integer not null,
	QUANTITY                                REAL NOT NULL,
	FK_ORDER_ASSIGNMENT                                INTEGER NOT NULL,
	FK_MEUN                                 INTEGER NOT NULL,
	FK_PRODUCT		      	        	    integer not null,
	FK_PRODUCT_INVENTORY                    INTEGER NULL,
	PRIORITY                                INTEGER NOT NULL,
	IS_DELETED                              INTEGER NOT NULL DEFAULT 0,
	CREATE_DATE                             INTEGER NOT NULL DEFAULT (strftime('%s','now') * 1000),
	CHANGE_DATE                             INTEGER NOT NULL DEFAULT (strftime('%s','now') * 1000),
	FEE                                     REAL NOT NULL DEFAULT 0,
	FREE_PRODUCT_CONDITION_ROW_ID           INTEGER,
	PRICE                                   REAL NOT NULL DEFAULT 0,
	NET_PRICE                               REAL NOT NULL DEFAULT 0,
	ADDITION_AMOUNT                         REAL NOT NULL DEFAULT 0,
	REDUCTION_AMOUNT                        REAL NOT NULL DEFAULT 0,
	DESCRIPTION                             TEXT NULL,
	FK_SLAR                                 INTEGER,
	FK_ORDER_ASSIGNMENT_ITEM_PARENT         INTEGER NULL,
	FK_SLPLCY_FREE_PRODUCT_POLICY           INTEGER NULL,
	FK_LKP_TYPE                             INTEGER NOT NULL DEFAULT 1 REFERENCES TBL_GN_LOOKUP (_id),
	SETTLEMENT_PERIOD                       TEXT,
	FK_PRODUCT_PACK                         INTEGER NULL,
	FK_PRODUCT_PACK_ITEM                    INTEGER NULL,
	PRODUCT_PACK_QUANTITY                   INTEGER NULL,
	FK_TRACKING_FACTOR_COLLECTION INTEGER NULL REFERENCES TBL_DM_TRACKING_FACTOR_COLLECTION (_id),
	IS_RECOMMENDED INTEGER NOT NULL DEFAULT 0,
	PRICE_BASED_UNIT_REF INTEGER NULL,
	PRICE_BASED_FEE INTEGER NULL,
	FOREIGN KEY (FK_ORDER_ASSIGNMENT) REFERENCES TBL_DM_ORDER_ASSIGNMENT (_id) ON DELETE CASCADE,
	foreign key (FK_MEUN) references TBL_DM_MEASUREMENT_UNIT (_id),
	foreign key (FK_PRODUCT) references TBL_DM_PRODUCT (_id),
	FOREIGN KEY (FK_SLAR) REFERENCES TBL_DM_SALES_AREA (_id),
	FOREIGN KEY (FK_ORDER_ASSIGNMENT_ITEM_PARENT) REFERENCES TBL_DM_ORDER_ASSIGNMENT_ITEM (_id),
	FOREIGN KEY (FK_SLPLCY_FREE_PRODUCT_POLICY) REFERENCES TBL_DM_SALES_POLICY (_id),
	FOREIGN KEY (FK_PRODUCT_INVENTORY) REFERENCES TBL_DM_PRODUCT_INVENTORY (_id),
	FOREIGN KEY (FK_PRODUCT_PACK) REFERENCES TBL_DM_PRODUCT_PACK (_id),
	FOREIGN KEY (FK_PRODUCT_PACK_ITEM) REFERENCES TBL_DM_PRDT_ITEM_PRODUCT_PACK (_id)
	);





CREATE TABLE TBL_DM_ORDER_ASSIGNMENT_SALES_POLICY_RESULT (
_id integer primary key autoincrement,
VALUE real null,
VALUE_TITLE text not null,
AMOUNT real,
IS_ALLOTMENTED integer not null,
IS_VALUE_CHANGED integer not null,
FK_SLPLCY integer not null,
FK_ORDER_ASSIGNMENT integer null,
FK_ORDER_ASSIGNMENT_ITEM integer null,
CREATE_DATE integer not null default (strftime('%s','now') * 1000),
CHANGE_DATE integer not null default (strftime('%s','now') * 1000),
iS_VIEWABLE INTEGER NOT NULL DEFAULT 0,
iS_FIXED INTEGER NOT NULL DEFAULT 0,
foreign key( FK_ORDER_ASSIGNMENT ) references TBL_DM_ORDER_ASSIGNMENT ( _id ) ON DELETE CASCADE,
foreign key( FK_ORDER_ASSIGNMENT_ITEM ) references TBL_DM_ORDER_ASSIGNMENT_ITEM ( _id ) ON DELETE CASCADE,
foreign key( FK_SLPLCY ) references TBL_DM_SALES_POLICY ( _id )
);

