insert into TBL_GN_LOOKUP(NAME, CODE, TYPE) values('قیمت فروش', 1, 'PRICE_TYPE');
insert into TBL_GN_LOOKUP(NAME, CODE, TYPE) values('قیمت مصرف کننده', 2, 'PRICE_TYPE');

create table TBL_DM_PRODUCT_PRICE(
	_id 				integer primary key autoincrement,	
	FK_LKP_PRICE_TYPE	integer not null,   
    FK_PRODUCT          integer not null,
    FK_PRODUCT_UNIT     integer not null,
    FK_CURRENCY         integer not null,
    FEE 				real not null default 0,
    DESCRIPTION			text,
	CREATE_DATE			integer default (strftime('%s','now')*1000),
	CHANGE_DATE			integer default (strftime('%s','now')*1000),	
    foreign key(FK_LKP_PRICE_TYPE) references TBL_GN_LOOKUP (_id),
    foreign key(FK_PRODUCT) references TBL_DM_PRODUCT (_id) ON DELETE CASCADE,
    foreign key(FK_PRODUCT_UNIT) references TBL_DM_MEASUREMENT_UNIT (_id),
    foreign key(FK_CURRENCY ) references  TBL_DM_CURRENCY (_id)
);

create index idx_TBL_DM_PRODUCT_PRICE_PK on TBL_DM_PRODUCT_PRICE (_id);
create index idx_TBL_DM_PRODUCT_PRICE_FK_LKP_PRICE_TYPE on TBL_DM_PRODUCT_PRICE (FK_LKP_PRICE_TYPE);
create index idx_TBL_DM_PRODUCT_PRICE_FK_PRODUCT on TBL_DM_PRODUCT_PRICE (FK_PRODUCT);
create index idx_TBL_DM_PRODUCT_PRICE_FK_PRODUCT_UNIT on TBL_DM_PRODUCT_PRICE (FK_PRODUCT_UNIT);
create index idx_TBL_DM_PRODUCT_PRICE_FK_CURRENCY  on TBL_DM_PRODUCT_PRICE (FK_CURRENCY);


create table TBL_DM_CUSTOMER_backup ( 
		_id 			integer primary key autoincrement,
		NAME			text not null, 
		CODE			text not null,
		STATE 			integer not null default 1,
		FK_LKP_TYPE		integer not null,
		NATIONAL_CODE 	text null,
		ECONOMIC_CODE	text null,
		FK_CSMR_PARENT 	integer null,
		SRV_PK			integer not null unique ON CONFLICT fail,
		IS_DELETED		integer not null default 0,
		CREATE_DATE		integer default (strftime('%s','now')*1000),
		CHANGE_DATE		integer default (strftime('%s','now')*1000),
		foreign key (FK_CSMR_PARENT) references TBL_DM_CUSTOMER (_id),
		foreign key (FK_LKP_TYPE) references TBL_GN_LOOKUP (_id)
);

insert into TBL_DM_CUSTOMER_backup 
	select _id, NAME, CODE, STATE, FK_LKP_TYPE, NATIONAL_CODE, ECONOMIC_CODE, FK_CSMR_PARENT, SRV_PK, IS_DELETED, CREATE_DATE, CHANGE_DATE
	from TBL_DM_CUSTOMER;

drop table TBL_DM_CUSTOMER;	
	
create table TBL_DM_CUSTOMER ( 
		_id 			integer primary key autoincrement,
		NAME			text not null, 
		CODE			text null,
		STATE 			integer not null default 1,
		FK_LKP_TYPE		integer not null,
		NATIONAL_CODE 	text null,
		ECONOMIC_CODE	text null,
		FK_CSMR_PARENT 	integer null,
		SRV_PK			integer null unique ON CONFLICT fail,
		FK_LKP_STATUS		integer null,
		IS_DELETED		integer not null default 0,
		CREATE_DATE		integer default (strftime('%s','now')*1000),
		CHANGE_DATE		integer default (strftime('%s','now')*1000),
		foreign key (FK_CSMR_PARENT) references TBL_DM_CUSTOMER (_id) ON DELETE CASCADE,
		foreign key (FK_LKP_TYPE) references TBL_GN_LOOKUP (_id)
);
		
create index idx_TBL_DM_CUSTOMER_NAME on TBL_DM_CUSTOMER (NAME);

create index idx_TBL_DM_CUSTOMER_CODE on TBL_DM_CUSTOMER (CODE);

create index idx_TBL_DM_CUSTOMER_IS_DELETED on TBL_DM_CUSTOMER (IS_DELETED);

create index idx_TBL_DM_CUSTOMER_SRV_PK on TBL_DM_CUSTOMER (SRV_PK);

insert into TBL_DM_CUSTOMER 
	(_id, NAME, CODE, STATE, FK_LKP_TYPE, NATIONAL_CODE, ECONOMIC_CODE, FK_CSMR_PARENT, SRV_PK, IS_DELETED, CREATE_DATE, CHANGE_DATE)
	select _id, NAME, CODE, STATE, FK_LKP_TYPE, NATIONAL_CODE, ECONOMIC_CODE, FK_CSMR_PARENT, SRV_PK, IS_DELETED, CREATE_DATE, CHANGE_DATE
	from TBL_DM_CUSTOMER_backup;

drop table TBL_DM_CUSTOMER_backup;

INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('ارسال موقت','0','SENDING_CUSTOMER_TYPE');

INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('تایید شده','1','SENDING_CUSTOMER_TYPE');

INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('ثبت موقت','2','SENDING_CUSTOMER_TYPE');

INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('اقدام به ارسال','3','SENDING_CUSTOMER_TYPE');

INSERT INTO TBL_GN_LOOKUP(NAME, CODE, TYPE) VALUES('ارسال با خطا','4','SENDING_CUSTOMER_TYPE');


